package cn.iocoder.yudao.module.order.controller.admin.merge;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.convert.orderTime.OrderTimeConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.orderTime.OrderTimeDO;
import cn.iocoder.yudao.module.order.dto.OrderBackInfoDto;
import cn.iocoder.yudao.module.order.vo.order.OrderBackVO;
import cn.iocoder.yudao.module.order.vo.orderTime.OrderTimeBackVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.order.vo.merge.*;
import cn.iocoder.yudao.module.order.dal.dataobject.merge.MergeDO;
import cn.iocoder.yudao.module.order.convert.merge.MergeConvert;
import cn.iocoder.yudao.module.order.service.merge.MergeService;

@Validated
@RestController
@Api(tags = "管理后台 - 订单合单申请")
@RequestMapping("/order/merge")
public class MergeController {

    @Resource
    private MergeService mergeService;

    @PostMapping("/create")
    @ApiOperation("创建订单合单申请")
    public CommonResult<Boolean> createMerge(@Valid @RequestBody List<MergeCreateReqVO> createReqVOS) {
        mergeService.createMerge(createReqVOS);
        return success(true);
    }

    @PutMapping("/update")
    @ApiOperation("更新订单合单申请")
    public CommonResult<Boolean> updateMerge(@Valid @RequestBody MergeUpdateReqVO updateReqVO) {
        mergeService.updateMerge(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/cancel")
    @ApiOperation("取消订单合单申请")
    public CommonResult<Boolean> cancelMerge(@RequestBody MergeQueryVO mergeQueryVO) {
        mergeService.cancelMerge(mergeQueryVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除订单合单申请")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteMerge(@RequestParam("id") Long id) {
        mergeService.deleteMerge(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得订单合单申请")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<MergeBackVO> getMerge(@RequestParam("id") Long id) {
        MergeDO merge = mergeService.getMerge(id);
        return success(MergeConvert.INSTANCE.convert(merge));
    }

    @GetMapping("/getMergeLogByMergedOrderNo")
    @ApiOperation("根据合并订单编号获得已合单的订单动态")
    public CommonResult<Map<String,List<OrderTimeDO>>> getMergeLogByMergedOrderNo(@RequestParam("mergedOrderNo") String mergedOrderNo) {
        Map<String,List<OrderTimeDO>> orderTimeDOS = mergeService.getMergeLogByMergedOrderNo(mergedOrderNo);
        return success(orderTimeDOS);
    }

    @GetMapping("/getMergeListByOrderNo")
    @ApiOperation("根据合并订单编号(或订单号)获得已合单列表和待合单列表")
    public CommonResult<Map<String,Object>> getMergeListByOrderNo(@RequestParam("mergedOrderNo") String mergedOrderNo,PageVO pageVO) {
        Map<String,Object> orderBackVOS = mergeService.getMergeListByOrderNo(mergedOrderNo,pageVO);
        return success(orderBackVOS);
    }

    @GetMapping("/getMergeListByMergeId")
    @ApiOperation("根据合并编号获得订单信息、已合单列表和待合单列表")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<List<OrderBackInfoDto>> getMergeListByMergeId(@RequestParam("id") Long id) {
        List<OrderBackInfoDto> orderBackVOS = mergeService.getMergeListByMergeId(id);
        return success(orderBackVOS);
    }

    @GetMapping("/list")
    @ApiOperation("获得订单合单申请列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<MergeBackVO>> getMergeList(@RequestParam("ids") Collection<Long> ids) {
        List<MergeDO> list = mergeService.getMergeList(ids);
        return success(MergeConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得订单合单申请分页")
    public CommonResult<PageResult<MergeBackVO>> getMergePage(@Valid MergeQueryVO query, PageVO page) {
        PageResult<MergeDO> pageResult = mergeService.getMergePage(query, page);
        return success(MergeConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出订单合单申请 Excel")
    @OperateLog(type = EXPORT)
    public void exportMergeExcel(@Valid MergeQueryVO query,
              HttpServletResponse response) throws IOException {
        List<MergeDO> list = mergeService.getMergeList(query);
        // 导出 Excel
        List<MergeBackVO> datas = MergeConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "订单合单申请.xls", "数据", MergeBackVO.class, datas);
    }

    @GetMapping("/getApproval")
    @ApiOperation("根据合并订单编号获得已合单的订单动态")
    public CommonResult<Boolean> getApproval(@RequestParam("id") String id,@RequestParam("result") int result) {
        mergeService.updateOrderMergeResult(id,result);
        return success(true);
    }
}
