package cn.iocoder.yudao.module.order.controller.admin.order;

import cn.hutool.core.collection.CollectionUtil;
import cn.iocoder.yudao.framework.common.util.spring.enums.UserTypeEnum;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.security.core.LoginUser;
import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import cn.iocoder.yudao.module.order.service.order.OrderAirService;
import cn.iocoder.yudao.module.order.service.order.OrderQueryService;
import cn.iocoder.yudao.module.order.vo.order.*;
import cn.iocoder.yudao.module.system.api.permission.RoleApi;
import cn.iocoder.yudao.module.system.api.permission.dto.RoleRespDTO;
import cn.iocoder.yudao.module.system.enums.ErrorCodeConstants;
import cn.iocoder.yudao.module.system.enums.permission.DataScopeEnum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.error;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.module.order.enums.ErrorCodeConstants.ORDER_ID_NOT_NULL;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.ROLE_NOT_EXISTS;

@Validated
@RestController
@Api(tags = "管理后台 - 空运订单相关管理")
@RequestMapping("/air/order")
@Slf4j
public class OrderAirController {

    @Resource
    private OrderQueryService orderQueryService;
    @Resource
    private OrderAirService orderAirService;
    @Resource
    private RoleApi roleApi;

    @GetMapping("/waiting/shipment/page")
    @ApiOperation("待出订单列表")
    public CommonResult<PageResult<OrderBackPageVO>> waitingShipmentOrderPage(OrderQueryVO query, PageVO page) {
        if (Objects.isNull(query)) {
            query = new OrderQueryVO();
        }
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setAirShipment(1); // 待出
        PageResult<OrderBackPageVO> pageResult = orderQueryService.orderPage(query, page);
        return success(pageResult);
    }

    @GetMapping("/data/scope/waiting/shipment/page")
    @ApiOperation("数据权限范围待出订单列表")
    public CommonResult<PageResult<OrderBackPageVO>> dataScpeWaitingShipmentOrderPage(OrderQueryVO query, PageVO page) {
        if (Objects.isNull(query)) {
            query = new OrderQueryVO();
        }
        LoginUser loginUser = SecurityFrameworkUtils.getLoginUser();
        if (Objects.isNull(loginUser)){
            return error(ErrorCodeConstants.USER_NOT_EXISTS);
        }
        List<RoleRespDTO> roleRespDTOS = roleApi.getRoles(loginUser.getRoleIds());
        if (Objects.isNull(roleRespDTOS)){
            return error(ROLE_NOT_EXISTS);
        }
        addDataScopeQuery(query, loginUser, roleRespDTOS);
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setAirShipment(1); // 待出
        PageResult<OrderBackPageVO> pageResult = orderQueryService.orderPage(query, page);
        return success(pageResult);
    }

    @GetMapping("/waiting/shipment/count")
    @ApiOperation("待出订单数量统计")
    public CommonResult<Long> waitingShipmentOrderCount() {
        OrderQueryVO query = new OrderQueryVO();
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setAirShipment(1); // 待出
        long count = orderQueryService.orderCount(query);
        return success(count);
    }

    @GetMapping("/data/scope/waiting/shipment/count")
    @ApiOperation("数据权限范围待出订单数量统计")
    public CommonResult<Long> dataScopeWaitingShipmentOrderCount() {
        OrderQueryVO query = new OrderQueryVO();
        LoginUser loginUser = SecurityFrameworkUtils.getLoginUser();
        if (Objects.isNull(loginUser)){
            return error(ErrorCodeConstants.USER_NOT_EXISTS);
        }
        List<RoleRespDTO> roleRespDTOS = roleApi.getRoles(loginUser.getRoleIds());
        if (Objects.isNull(roleRespDTOS)){
            return error(ROLE_NOT_EXISTS);
        }
        addDataScopeQuery(query, loginUser, roleRespDTOS);
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setAirShipment(1); // 待出
        long count = orderQueryService.orderCount(query);
        return success(count);
    }



    @GetMapping("/can/shipment/page")
    @ApiOperation("可出订单列表")
    public CommonResult<PageResult<OrderBackPageVO>> canShipmentPage(OrderQueryVO query, PageVO page) {
        if (Objects.isNull(query)) {
            query = new OrderQueryVO();
        }
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setAirShipment(12); // 可出
        PageResult<OrderBackPageVO> pageResult = orderQueryService.orderPage(query, page);
        return success(pageResult);
    }

    @GetMapping("/data/scope/can/shipment/page")
    @ApiOperation("数据权限范围可出订单列表")
    public CommonResult<PageResult<OrderBackPageVO>> dataScopeCanShipmentPage(OrderQueryVO query, PageVO page) {
        if (Objects.isNull(query)) {
            query = new OrderQueryVO();
        }
        LoginUser loginUser = SecurityFrameworkUtils.getLoginUser();
        if (Objects.isNull(loginUser)){
            return error(ErrorCodeConstants.USER_NOT_EXISTS);
        }
        List<RoleRespDTO> roleRespDTOS = roleApi.getRoles(loginUser.getRoleIds());
        if (Objects.isNull(roleRespDTOS)){
            return error(ROLE_NOT_EXISTS);
        }
        addDataScopeQuery(query, loginUser, roleRespDTOS);
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setAirShipment(12); // 可出
        PageResult<OrderBackPageVO> pageResult = orderQueryService.orderPage(query, page);
        return success(pageResult);
    }

    @GetMapping("/ready-stock-processing/shipment/page")
    @ApiOperation("备货中订单列表")
    public CommonResult<PageResult<OrderBackPageVO>> readyStockProcessingShipmentPage(OrderQueryVO query, PageVO page) {
        if (Objects.isNull(query)) {
            query = new OrderQueryVO();
        }
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setAirShipment(3); // 备货中
        PageResult<OrderBackPageVO> pageResult = orderQueryService.orderPage(query, page);
        return success(pageResult);
    }

    @GetMapping("/ready-stock/shipment/page")
    @ApiOperation("已备货订单列表")
    public CommonResult<PageResult<OrderBackPageVO>> readyStockShipmentPage(OrderQueryVO query, PageVO page) {
        if (Objects.isNull(query)) {
            query = new OrderQueryVO();
        }
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setAirShipment(4); // 已备货
        PageResult<OrderBackPageVO> pageResult = orderQueryService.orderPage(query, page);
        return success(pageResult);
    }

    @GetMapping("/can-ready-stock/shipment/page")
    @ApiOperation(value = "备货订单列表", notes = "可出(待备货)、备货中、已备货订单列表")
    public CommonResult<PageResult<OrderBackPageVO>> canAndReadyStockShipmentPage(OrderQueryVO query, PageVO page) {
        if (Objects.isNull(query)) {
            query = new OrderQueryVO();
        }
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        //bug: #4651 pda空运待备货列表，显示规则优化. [期望] 默认显示待备货，未完成备货订单，但是可以搜索到已完成备货订单
        if (StringUtils.isNotEmpty(query.getOrderNo())) {
            query.setAirShipment(10); // 可出-备货中-已备货
        } else {
            query.setAirShipment(12); //12 可出、备货中
        }
        PageResult<OrderBackPageVO> pageResult = orderQueryService.orderPage(query, page);
        return success(pageResult);
    }

    @GetMapping("/waiting-can-ready-stock/shipment/page")
    @ApiOperation(value = "空运出货全部状态订单列表", notes = "待出、可出(待备货)、备货中、已备货订单列表")
    public CommonResult<PageResult<OrderBackPageVO>> waitingAndCanAndReadyStockShipmentOrderPage(OrderQueryVO query, PageVO page) {
        if (Objects.isNull(query)) {
            query = new OrderQueryVO();
        }
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setAirShipment(11); // 待出-可出-备货中-已备货
        PageResult<OrderBackPageVO> pageResult = orderQueryService.orderPage(query, page);
        return success(pageResult);
    }


    @PutMapping("/can/shipment/{orderId}")
    @ApiOperation("确认空运待出订单可出")
    @ApiImplicitParam(name = "orderId", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> canShipment(@PathVariable("orderId") Long orderId) {
        orderAirService.can(orderId);
        return success(true);
    }

    @PutMapping("/can/shipment/")
    @ApiOperation("批量确认空运待出订单可出")
    public CommonResult<Boolean> batchCanShipment(@RequestBody OrderAirQuery query) {
        if (Objects.isNull(query) || CollectionUtil.isEmpty(query.getOrderIdList())) {
            return error(ORDER_ID_NOT_NULL);
        }
        orderAirService.canByOrderIds(query.getOrderIdList());
        return success(true);
    }

    @PutMapping("/not/can/shipment/{orderId}")
    @ApiOperation("修改空运待备货、备货中、已备货订单不可出")
    @ApiImplicitParam(name = "orderId", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> notCanShipment(@PathVariable("orderId") Long orderId) {
        orderAirService.notCan(orderId);
        return success(true);
    }

    @PutMapping("/not/can/shipment/")
    @ApiOperation("批量修改空运待备货、备货中、已备货订单不可出")
    public CommonResult<Boolean> batchNotCanShipment(@RequestBody OrderAirQuery query) {
        if (Objects.isNull(query) || CollectionUtil.isEmpty(query.getOrderIdList())) {
            return error(ORDER_ID_NOT_NULL);
        }
        orderAirService.notCanByOrderIds(query.getOrderIdList());
        return success(true);
    }

    @PutMapping("/manual-exception/batch")
    @ApiOperation("批量转异")
    public CommonResult<Boolean> manualExceptionBatch(@RequestBody OrderManualExceptionBatchReqVO orderManualExceptionBatchReqVO) {

        List<Long> orderIds = orderManualExceptionBatchReqVO.getOrderIds();

        if (CollectionUtil.isEmpty(orderIds)) {
            return error(ORDER_ID_NOT_NULL);
        }

        orderAirService.manualExceptionBatch(orderManualExceptionBatchReqVO);

        return success(true);
    }


    private static void addDataScopeQuery(OrderQueryVO query, LoginUser loginUser, List<RoleRespDTO> roleRespDTOS) {
        List<Long> deptIdList = new ArrayList<>();
        boolean isAll = Boolean.FALSE;
        for (RoleRespDTO roleRespDTO : roleRespDTOS) {
            DataScopeEnum dataScopeEnum = DataScopeEnum.valueOf(roleRespDTO.getDataScope());
            switch (dataScopeEnum){
                case ALL:
                    // 全部数据权限，不限制
                    isAll = Boolean.TRUE;
                    break;
                case DEPT_CUSTOM:
                    // 指定部门数据权限
                    if (CollectionUtil.isNotEmpty(roleRespDTO.getDataScopeDeptIds())) {
                        deptIdList.addAll(roleRespDTO.getDataScopeDeptIds());
                    }
                    break;
                case DEPT_ONLY:
                    // 部门数据权限
                    if (Objects.nonNull(loginUser.getDeptId())) {
                        deptIdList.add(loginUser.getDeptId());
                    }
                    break;
                case DEPT_AND_CHILD:
                    // 部门及以下数据权限
                    deptIdList.add(loginUser.getDeptId());
                    break;
            }
        }
        if (!isAll){
            // 非全部数据权限时查询限制条件
            if (CollectionUtil.isEmpty(deptIdList) || deptIdList.size() == 0){
                // 没有部门限制条件时，只查询当前用户自己的
                query.setCreator(String.valueOf(loginUser.getId()));
            }else {
                // 查询限定部门的数据
                query.setDeptIdList(deptIdList);
            }
        }
    }

}
