package cn.iocoder.yudao.module.order.controller.admin.order;

import cn.iocoder.yudao.framework.common.util.spring.enums.UserTypeEnum;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.i18n.core.I18nMessage;
import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.framework.security.core.LoginUser;
import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import cn.iocoder.yudao.module.order.dto.OrderQueryDTO;
import cn.iocoder.yudao.module.system.api.file.FileMakeApi;
import cn.iocoder.yudao.module.system.api.file.dto.FileMakeReqDTO;
import cn.iocoder.yudao.module.system.enums.download.DownloadTypeEnum;
import com.alibaba.fastjson.JSONObject;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.module.order.enums.ErrorCodeConstants.CONTAINER_NUMBER_NOT_NULL;

@Validated
@RestController
@Api(tags = "管理后台 - 订单导出管理")
@RequestMapping("/ecw/order/export")
@Slf4j
public class OrderExportController {

    @Resource
    private FileMakeApi fileMakeApi;


    @GetMapping("/search")
    @ApiOperation(value = "参数搜索导出订单管理 Excel", notes = "参数搜索和指定订单导出管理")
    @OperateLog(type = EXPORT)
    public CommonResult<Boolean> exportOrderExcel(OrderQueryDTO query) {
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }

    @GetMapping("my/search")
    @ApiOperation(value = "参数搜索导出我的订单管理 Excel", notes = "参数搜索和指定我的订单导出管理")
    @OperateLog(type = EXPORT)
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> exportMyOrderExcel(OrderQueryDTO query) {
        Long salesmanId = SecurityFrameworkUtils.getLoginUserId(); // 获取当前登录用户ID
        query.setUserType(UserTypeEnum.ADMIN.getValue());
//        query.setSalesmanId(salesmanId);
        query.setCreator(String.valueOf(salesmanId));
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("我的订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }

    public void caseStatus(List<Integer> status, OrderQueryDTO query){
        if (CollectionUtils.isNotEmpty(status)  && status.size()>0) {
            List<Integer> statusList =new ArrayList<>() ;

            status.forEach(statu->{
                if(statu>10000){
                    combinedState(statu, query,statusList);
                }

            });
            statusList.stream().distinct();
            List<Integer>  list= new ArrayList<>()  ;
            list.addAll(status.stream().filter(s->s <10000).collect(Collectors.toList())) ;
            list.addAll(statusList.stream().distinct().collect(Collectors.toList()));

            query.setStatusList(list) ;
        }else if(CollectionUtils.isNotEmpty(status)  && status.size()==0){
            status =null;
        }
    }



    private void combinedState(Integer asStatus, OrderQueryDTO query,List<Integer> statusList) {


        switch (asStatus) {
            case 12325:
                //this.status = 12;
                statusList.add(12);

                query.setShipmentState(325);
                break;
            case 10501:
                // 空运待出
                //this.status = 5;
                statusList.add(5);
                //query.setTransportId(3); // 空运待出查询，只查空运的订单
                if(Objects.nonNull(query.getTransportId())){
                    query.setTransportId(3);
                }
                query.setAirShipment(1);
                //this.auditType = 0;
                if(CollectionUtils.isEmpty(query.getAuditType())){
                    List<Integer>  audits= new ArrayList<>();
                    query.setAuditType(audits)  ;
                    query.getAuditType().add(0)  ;
                }else {
                    query.getAuditType().add(0)  ;
                }

                //this.abnormalState = 0;
                if(CollectionUtils.isEmpty(query.getAbnormalState())){
                    List<Integer>  audits= new ArrayList<>();
                    query.setAbnormalState(audits);

                    query.getAbnormalState().add(0) ;
                }else {
                    query.getAbnormalState().add(0) ;
                }

                break;
            case 10502:
                // 空运可出
                //this.status = 5;
                statusList.add(5);
                //query.setTransportId(3); // 空运待出查询，只查空运的订单
                if(Objects.nonNull(query.getTransportId())){
                    query.setTransportId(3);
                }
                query.setAirShipment(12) ; // 可出、备货中
                break;
            case 10503:
                // 空运已备货
                //this.status = 5;
                statusList.add(5);
                //query.setTransportId(3); // 空运待出查询，只查空运的订单
                if(Objects.nonNull(query.getTransportId())){
                    query.setTransportId(3);
                }
                query.setAirShipment(4) ; // 已备货
                break;
            case 10504:
                // 待排单
                //this.status = 5;
                statusList.add(5);
                if (Objects.nonNull(query.getTransportId()) && query.getTransportId() == 3) {
                    // 空运无需判断备货状态 可出、备货中、已备货
                    query.setAirShipment(10) ;
                }else {
                    // 兼容空运已入仓的可出、备货中、已备货，且无异常无审批，海运的已入仓无异常无审批
                    query.setAirShipment(20) ;
                }
                //this.auditType = 0;
                if(CollectionUtils.isEmpty(query.getAuditType())){
                    List<Integer>  audits= new ArrayList<>();

                    query.setAuditType(audits)  ;
                    query.getAuditType().add(0);
                }else {
                    query.getAuditType().add(0)  ;
                }
                //this.abnormalState = 0;

                if(CollectionUtils.isEmpty(query.getAbnormalState())){
                    List<Integer>  audits= new ArrayList<>();
                    query.setAbnormalState(audits);

                    query.getAbnormalState().add(0) ;
                }else {
                    query.getAbnormalState().add(0) ;
                }
                break;
            case 132411:
                // 空运已出货
                //this.status = 32;
                statusList.add(32);
                //query.setTransportId(3); // 空运待出查询，只查空运的订单
                if(Objects.nonNull(query.getTransportId())){
                    query.setTransportId(3);
                }
                query.setShipmentState(411);
                break;
            case 132412:
                // 空运已出仓
                //this.status = 32;
                statusList.add(32);
                //query.setTransportId(3); // 空运待出查询，只查空运的订单
                if(Objects.nonNull(query.getTransportId())){
                    query.setTransportId(3);
                }
                query.setShipmentState(412);
                break;
            case 132409:
                // 空运已理货
                //this.status = 32;
                statusList.add(32);
                // 空运待出查询，只查空运的订单
                if(Objects.nonNull(query.getTransportId())){
                    query.setTransportId(3);
                }
                query.setShipmentState( 409);
                break;
            case 118428:
                // 空运已到港
                //this.status = 18;
                statusList.add(18);
                //query.setTransportId(3); // 空运待出查询，只查空运的订单
                if(Objects.nonNull(query.getTransportId())){
                    query.setTransportId(3);
                }
                query.setShipmentState( 428);
                break;
        }

    }

    @GetMapping("dept/search")
    @ApiOperation(value = "参数搜索导出部门订单管理 Excel", notes = "参数搜索和指定部门订单导出管理")
    @OperateLog(type = EXPORT)
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> exportDeptOrderExcel(OrderQueryDTO query) {
        LoginUser loginUser = SecurityFrameworkUtils.getLoginUser(); // 获取当前登录用户ID
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setDeptId(Objects.isNull(loginUser) || Objects.isNull(loginUser.getDeptId()) ? 0L : loginUser.getDeptId());
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("部门订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }


    @GetMapping("/cargo/control/search")
    @ApiOperation("参数搜索导出控货订单列表")
    @OperateLog(type = EXPORT)
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> exportCargoControlOrderExcel(OrderQueryDTO query) {
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.CARGO_CONTROL_ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("控货订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }

    @GetMapping("/export-exception")
    @ApiOperation("导出异常单统计 Excel")
    @OperateLog(type = EXPORT)
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> exportOrderExceptionExcel(OrderQueryDTO query) {
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.EXCEPTION_ORDER_STATISTICS_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("异常订单统计导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }

    @GetMapping("/export-heavyOrder")
    @ApiOperation("导出重货单统计 Excel")
    @OperateLog(type = EXPORT)
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> exportHeavyOrder(OrderQueryDTO query) {
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.HEAVY_ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("重货订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }


    @GetMapping("/export-returnOrder")
    @ApiOperation("导出退仓单统计 Excel")
    @OperateLog(type = EXPORT)
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> exportReturnOrder(OrderQueryDTO query) {
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.RETURN_ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("退仓订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }

    @GetMapping("/export-saleRepay")
    @ApiOperation("导出售后赔偿金额统计 Excel")
    @OperateLog(type = EXPORT)
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> exportSaleRepay(OrderQueryDTO query, HttpServletResponse response) throws IOException {
//        List<OrderSaleRepayExcelVo> list = orderQueryService.getSaleRepayExcelList(query);
//        String sheetName = I18nMessage.getLang() == 0 ? "售后赔偿金额统计" : "sale repay statistics";
//        ExcelUtils.write(response, "售后赔偿金额统计.xls", sheetName, OrderSaleRepayExcelVo.class, list);
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.SALE_REPAY_ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("售后赔偿订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }

    @GetMapping("/export-customDatas")
    @ApiOperation("导出报关数统计 Excel")
    @OperateLog(type = EXPORT)
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> exportCustomsDatas(OrderQueryDTO query, HttpServletResponse response) throws IOException {
//        List<OrderCustomsDatasExcelVo> list = orderQueryService.getCustomsDatasExcelList(query);
//        String sheetName = I18nMessage.getLang() == 0 ? "报关数据统计" : "customs data statistics";
//        ExcelUtils.write(response, "报关数据统计.xls", sheetName, OrderCustomsDatasExcelVo.class, list);
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.CUSTOMS_ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("报关订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }

    @GetMapping("/export-shipDatas")
    @ApiOperation("导出客户出货量统计 Excel")
    @OperateLog(type = EXPORT)
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> exportShippingDatas(OrderQueryDTO query, HttpServletResponse response) throws IOException {
//        List<OrderShipDataExcelVo> list = orderQueryService.getShipDatasExcelList(query);
//        String sheetName = I18nMessage.getLang() == 0 ? "客户出货量统计" : "shipping data statistics";
//        ExcelUtils.write(response, "客户出货量统计.xls", sheetName, OrderShipDataExcelVo.class, list);
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.SHIPPING_ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("出货订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }

    @GetMapping("/export-shipFee")
    @ApiOperation("导出预付运费统计 Excel")
    @OperateLog(type = EXPORT)
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> exportShipFee(OrderQueryDTO query, HttpServletResponse response) throws IOException {
//        List<OrderShipFeeExcelVo> list = orderQueryService.getShipFeeExcelList(query);
//        String sheetName = I18nMessage.getLang() == 0 ? "预付运费统计" : "ship fee statistics";
//        ExcelUtils.write(response, "预付运费统计.xls", sheetName, OrderShipFeeExcelVo.class, list);
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.ADVANCE_ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("预付订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }

    @GetMapping("/can-shipment/search")
    @ApiOperation(value = "参数搜索导出待备货(可出-备货中)订单管理 Excel", notes = "参数搜索和指定待备货订单导出管理")
    @OperateLog(type = EXPORT)
    public CommonResult<Boolean> canShipmentOrderExcel(OrderQueryDTO query, HttpServletResponse response) throws IOException {
        if (Objects.isNull(query)){
            query = new OrderQueryDTO();
        }
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setAirShipment(12); // 可出、备货中
//        orderQueryService.exportOrderExcel(response, query);
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("待备货(可出-备货中)订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }

    @GetMapping("/ready-stock/search")
    @ApiOperation(value = "参数搜索导出备货订单管理 Excel", notes = "参数搜索和指定备货订单导出管理")
    @OperateLog(type = EXPORT)
    public CommonResult<Boolean> readyStockOrderExcel(OrderQueryDTO query, HttpServletResponse response) throws IOException {
        if (Objects.isNull(query)){
            query = new OrderQueryDTO();
        }
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setAirShipment(10); // 可出-备货中-已备货
//        orderQueryService.exportOrderExcel(response, query);
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("备货(可出-备货中-已备货)订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }

    @GetMapping("/waiting-shipment/search")
    @ApiOperation(value = "参数搜索导出待出订单管理 Excel", notes = "参数搜索和指定待出订单导出管理")
    @OperateLog(type = EXPORT)
    public CommonResult<Boolean> waitingShipmentOrderExcel(OrderQueryDTO query, HttpServletResponse response) throws IOException {
        if (Objects.isNull(query)){
            query = new OrderQueryDTO();
        }
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        query.setAirShipment(1); // 待出
//        orderQueryService.exportOrderExcel(response, query);
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("待出订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }


    @GetMapping("/export-order-summary")
    @ApiOperation("导出自编号订单汇总列表 Excel")
    @OperateLog(type = EXPORT)
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> exportOrderSummary(OrderQueryDTO query, HttpServletResponse response) throws IOException {
        if (StringUtils.isBlank(query.getContainerNumber())){
            throw exception(CONTAINER_NUMBER_NOT_NULL);
        }
//        PageVO page = new PageVO();
//        page.setRows(10000);
//        page.setPage(1);
//        PageResult<OrderBackPageVO> orderPage = orderQueryService.orderPage(query, page);
//        if (CollectionUtil.isNotEmpty(orderPage.getList())) {
//            String nameZh = String.format("自编号%s的订单费用汇总统计", query.getContainerNumber());
//            String nameEn = String.format("Summary Statistics of Order Expenses from ID%s", query.getContainerNumber());
//            List<OrderCostSummaryDto> orderCostSummaryDtoList = new ArrayList<>();
//            for (int i = 0; i < orderPage.getList().size(); i++) {
//                OrderBackPageVO back = orderPage.getList().get(i);
//                OrderCostSummaryDto summaryDto = orderQueryService.getOrderCostSummaryDto(null, back);
//                summaryDto.setNo(String.valueOf(i+1));
//                orderCostSummaryDtoList.add(summaryDto);
//            }
//            String sheetName = I18nMessage.getLang() == 0 ? nameZh : nameEn;
//            ExcelUtils.write(response, sheetName+".xls", sheetName, OrderCostSummaryDto.class, orderCostSummaryDtoList);
//        }
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.CONTAINER_NUMBER_ORDER_SEARCH_EXCEL_EXPORT.getType());
        reqDTO.setName("自编号订单导出Excel");
        reqDTO.setBusinessNo(query.getContainerNumber());
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        caseStatus(query.getStatus(),query);
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        return success(true);
    }
}
