package cn.iocoder.yudao.module.order.controller.admin.orderCargoControl;

import cn.hutool.core.collection.CollectionUtil;
import cn.iocoder.yudao.framework.common.util.spring.enums.UserTypeEnum;
import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.framework.limiter.dynamic.DynamicRateLimiter;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.dal.dataobject.orderCargoControlPick.OrderCargoControlPickDO;
import cn.iocoder.yudao.module.order.dto.OrderCargoControlReleaseInfoDto;
import cn.iocoder.yudao.module.order.service.orderCargoControlPick.OrderCargoControlPickService;
import cn.iocoder.yudao.module.order.vo.order.OrderBackPageVO;
import cn.iocoder.yudao.module.order.vo.order.OrderQueryVO;
import cn.iocoder.yudao.module.order.vo.order.OrderSendSmsReqVO;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.*;

import javax.annotation.Resource;
import javax.validation.*;
import java.util.*;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;

import static cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils.getLoginUserId;
import static cn.iocoder.yudao.module.order.enums.ErrorCodeConstants.ORDER_CARGO_CONTROL_PICK_NOT_EXISTS;

import cn.iocoder.yudao.module.order.vo.orderCargoControl.*;
import cn.iocoder.yudao.module.order.service.orderCargoControl.OrderCargoControlService;

@Validated
@RestController
@Api(tags = "管理后台 - 订单控货人信息")
@RequestMapping("/ecw/order-cargo-control")
public class OrderCargoControlController {

    @Autowired
    private OrderCargoControlService orderCargoControlService;
    @Resource
    private OrderCargoControlPickService orderCargoControlPickService;

    @PostMapping("/create")
    @DynamicRateLimiter(base = "#Headers['Authorization']", permits = 1)
    @Idempotent(timeout = 5)
    @ApiOperation("创建订单控货人信息")
    public CommonResult<Long> createOrderCargoControl(@Valid @RequestBody OrderCargoControlCreateReqVO createReqVO) {
        return success(orderCargoControlService.createOrderCargoControl(createReqVO, null));
    }





    @GetMapping("/info/{orderId}")
    @ApiOperation("获得订单控货权转移编辑详情")
    @ApiImplicitParam(name = "orderId", value = "订单ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderCargoControlBackVO> getOrderCargoControlInfo(@PathVariable("orderId") Long orderId) {
        OrderCargoControlBackVO backVO = orderCargoControlService.getOrderCargoControlInfo(orderId);
        return success(backVO);
    }


    @GetMapping("/release/info/{orderId}")
    @ApiOperation("获得控货订单放货编辑详情")
    @ApiImplicitParam(name = "orderId", value = "订单ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderCargoControlReleaseInfoDto> getOrderCargoControlReleaseInfo(@PathVariable("orderId") Long orderId) {
        OrderCargoControlReleaseInfoDto releaseInfoDto = orderCargoControlService.getOrderCargoControlReleaseInfo(orderId);
        return success(releaseInfoDto);
    }

//    @GetMapping("/list")
//    @ApiOperation("获得订单控货人信息列表")
//    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
//    @PreAuthorize("@ss.hasPermission('ecw:order-cargo-control:query')")
//    public CommonResult<List<OrderCargoControlBackVO>> getOrderCargoControlList(@RequestParam("ids") Collection<Long> ids) {
//        List<OrderCargoControlDO> list = orderCargoControlService.getOrderCargoControlList(ids);
//        return success(OrderCargoControlConvert.INSTANCE.convertList(list));
//    }


    /*
     控货订单列表
     */
    @GetMapping("/cargo/control/order")
    @ApiOperation("获得控货订单列表查询订单分页")
    public CommonResult<PageResult<OrderBackPageVO>> cargoControlOrderPage(OrderQueryVO query, PageVO page) {
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        PageResult<OrderBackPageVO> pageResult =
                orderCargoControlService.cargoControlOrderPage(query, page);
        return success(pageResult);
    }
    @GetMapping("/warning/cargo/control/order")
    @ApiOperation("获得预警控货订单列表查询订单分页")
    public CommonResult<PageResult<OrderBackPageVO>> warningCargoControlOrderPage(OrderQueryVO query, PageVO page) {
        query.setUserType(UserTypeEnum.ADMIN.getValue());
        PageResult<OrderBackPageVO> pageResult =
                orderCargoControlService.warningCargoControlOrderPage(query, page);
        return success(pageResult);
    }

    @PutMapping("/review/{orderId}")
    @ApiOperation("批量复合订单控货人放货")
    public CommonResult<Boolean> reviewOrderCargoControlPick(@PathVariable("orderId") Long orderId) {
        List<OrderCargoControlPickDO> orderCargoControlPickDOList = orderCargoControlPickService.list(new LambdaQueryWrapper<OrderCargoControlPickDO>()
                .eq(OrderCargoControlPickDO::getOrderId, orderId)
                .eq(OrderCargoControlPickDO::getStatus, 1));
        if (CollectionUtil.isEmpty(orderCargoControlPickDOList)) {
            throw exception(ORDER_CARGO_CONTROL_PICK_NOT_EXISTS);
        }
        for (OrderCargoControlPickDO orderCargoControlPickDO : orderCargoControlPickDOList) {
            orderCargoControlPickService.reviewOrderCargoControlPick(orderCargoControlPickDO);
        }
        return success(Boolean.TRUE);
    }

//    @GetMapping("/export-excel")
//    @ApiOperation("导出订单控货人信息 Excel")
//    @PreAuthorize("@ss.hasPermission('ecw:order-cargo-control:export')")
//    @OperateLog(type = EXPORT)
//    public void exportOrderCargoControlExcel(@Valid OrderCargoControlQueryVO query,
//                                             HttpServletResponse response) throws IOException {
//        List<OrderCargoControlDO> list = orderCargoControlService.getOrderCargoControlList(query);
//        // 导出 Excel
//        List<OrderCargoControlBackVO> datas = OrderCargoControlConvert.INSTANCE.convertList(list);
//        ExcelUtils.write(response, "订单控货人信息.xls", "数据", OrderCargoControlBackVO.class, datas);
//    }



    @PostMapping("/send-sms-code")
    @ApiOperation(value = "发送手机验证码", notes = "此接口只适用发送场景(4 控货全转移 5 放货验证短信 6 放货成功通知)")
    @OperateLog(enable = false) // 避免 Post 请求被记录操作日志
    public CommonResult<Boolean> sendSmsCode(@RequestBody @Valid OrderSendSmsReqVO reqVO) {
        orderCargoControlService.sendSmsCode(getLoginUserId(), reqVO, null);
        return success(true);
    }
}
