package cn.iocoder.yudao.module.order.controller.admin.orderControlLog;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import java.util.*;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.module.order.vo.orderControlLog.*;
import cn.iocoder.yudao.module.order.dal.dataobject.orderControlLog.OrderControlLogDO;
import cn.iocoder.yudao.module.order.convert.orderControlLog.OrderControlLogConvert;
import cn.iocoder.yudao.module.order.service.orderControlLog.OrderControlLogService;

@Validated
@RestController
@Api(tags = "管理后台 - 订单控货日志")
@RequestMapping("/order/order-control-log")
public class OrderControlLogController {

    @Resource
    private OrderControlLogService orderControlLogService;

    @GetMapping("/get")
    @ApiOperation("获得订单控货日志")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('order:order-control-log:query')")
    public CommonResult<OrderControlLogBackVO> getOrderControlLog(@RequestParam("id") Long id) {
        OrderControlLogDO orderControlLog = orderControlLogService.getOrderControlLog(id);
        return success(OrderControlLogConvert.INSTANCE.convert(orderControlLog));
    }

    @GetMapping("/list/{orderId}")
    @ApiOperation("获得订单控货日志列表")
    @ApiImplicitParam(name = "orderId", value = "订单id", required = true, example = "1024,2048", dataTypeClass = List.class)
//    @PreAuthorize("@ss.hasPermission('order:order-control-log:query')")
    public CommonResult<List<OrderControlLogBackVO>> getOrderControlLogListByOrderId(@PathVariable("orderId") Long orderId) {
        List<OrderControlLogDO> list = orderControlLogService.getOrderControlLogListByOrderId(orderId, null);
        return success(OrderControlLogConvert.INSTANCE.convertList(list));
    }

}
