package cn.iocoder.yudao.module.order.controller.admin.orderCount;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.dal.dataobject.orderException.OrderExceptionDO;
import cn.iocoder.yudao.module.order.dto.OrderCostSummaryDto;
import cn.iocoder.yudao.module.order.dto.OrderDetailSummaryDto;
import cn.iocoder.yudao.module.order.service.order.OrderQueryService;
import cn.iocoder.yudao.module.order.service.orderException.OrderExceptionService;
import cn.iocoder.yudao.module.order.vo.order.OrderBackPageVO;
import cn.iocoder.yudao.module.order.vo.order.OrderQueryVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;
import java.util.stream.Collectors;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.error;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.module.order.enums.ErrorCodeConstants.CONTAINER_NUMBER_NOT_NULL;

@Validated
@RestController
@Api(tags = "管理后台 - 订单统计")
@RequestMapping("/ecw/orderCount")
@Slf4j
public class OrderCountController {

    @Resource
    private OrderExceptionService orderExceptionService;
    @Resource
    private OrderQueryService orderQueryService;


    @GetMapping("/get")
    @ApiOperation("获得编辑详情订单")
    public CommonResult<Map<String,Integer>> getOrder() {
        Map<String,Integer> map = new HashMap(4);
        Long aLong = orderExceptionService.selectCount(OrderExceptionDO::getOrderExceptionStatus, 0);
        map.put("exceptionCount",aLong.intValue());
        return CommonResult.success(map);
    }

    @GetMapping("/containerNumber/orderSummary")
    @ApiOperation("自编号的订单费用汇总")
    public CommonResult<PageResult<OrderCostSummaryDto>> orderSummaryByOrderId(OrderQueryVO query, PageVO page) {
        if (StringUtils.isBlank(query.getContainerNumber())){
            return error(CONTAINER_NUMBER_NOT_NULL);
        }
        PageResult<OrderCostSummaryDto> summaryDtoPage = new PageResult<>();
        PageResult<OrderBackPageVO> orderPage = orderQueryService.orderPage(query, page);
        BeanUtils.copyProperties(orderPage, summaryDtoPage);
        summaryDtoPage.setTotal(orderPage.getTotal());
        summaryDtoPage.setList(orderPage.getList().stream().map(back -> orderQueryService.getOrderCostSummaryDto(null, back)).collect(Collectors.toList()));
        return success(summaryDtoPage);
    }

    @GetMapping("/orderSummary/{orderId}")
    @ApiOperation("订单费用汇总")
    @ApiImplicitParam(value = "订单id", name = "orderId", required = true, dataTypeClass = Long.class)
    public CommonResult<OrderCostSummaryDto> orderSummaryByOrderId(@PathVariable("orderId") Long orderId) {
        return success(orderQueryService.orderSummaryByOrderId(orderId));
    }

    @GetMapping("/orderDetailSummary/{orderId}")
    @ApiOperation("订单费用明细汇总")
    @ApiImplicitParam(value = "订单id", name = "orderId", required = true, dataTypeClass = Long.class)
    public CommonResult<OrderDetailSummaryDto> orderDetailSummaryByOrderId(@PathVariable("orderId")Long orderId) {
        return success(orderQueryService.orderDetailSummaryByOrderId(orderId));
    }

}
