package cn.iocoder.yudao.module.order.controller.admin.orderExceptionChannelPrice;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.module.order.convert.orderExceptionChannelPrice.OrderExceptionChannelPriceConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.orderExceptionChannelPrice.OrderExceptionChannelPriceDO;
import cn.iocoder.yudao.module.order.service.orderExceptionChannelPrice.OrderExceptionChannelPriceService;
import cn.iocoder.yudao.module.order.vo.orderExceptionChannelPrice.OrderExceptionChannelPriceBackVO;
import cn.iocoder.yudao.module.order.vo.orderExceptionChannelPrice.OrderExceptionChannelPriceCreateReqVO;
import cn.iocoder.yudao.module.order.vo.orderExceptionChannelPrice.OrderExceptionChannelPriceQueryVO;
import cn.iocoder.yudao.module.order.vo.orderExceptionChannelPrice.OrderExceptionChannelPriceUpdateReqVO;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "管理后台 - 不可出渠道异常商品价格")
@RequestMapping("/order/exception-channel-price")
public class OrderExceptionChannelPriceController {

    @Resource
    private OrderExceptionChannelPriceService exceptionChannelPriceService;

    @PostMapping("/create")
    @ApiOperation("创建不可出渠道异常商品价格")
    public CommonResult<Long> createExceptionChannelPrice(@Valid @RequestBody OrderExceptionChannelPriceCreateReqVO createReqVO) {
        return success(exceptionChannelPriceService.createExceptionChannelPrice(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新不可出渠道异常商品价格")
    public CommonResult<Boolean> updateExceptionChannelPrice(@Valid @RequestBody OrderExceptionChannelPriceUpdateReqVO updateReqVO) {
        exceptionChannelPriceService.updateExceptionChannelPrice(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除不可出渠道异常商品价格")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteExceptionChannelPrice(@RequestParam("id") Long id) {
        exceptionChannelPriceService.deleteExceptionChannelPrice(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得不可出渠道异常商品价格")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderExceptionChannelPriceBackVO> getExceptionChannelPrice(@RequestParam("id") Long id) {
        OrderExceptionChannelPriceDO exceptionChannelPrice = exceptionChannelPriceService.getExceptionChannelPrice(id);
        return success(OrderExceptionChannelPriceConvert.INSTANCE.convert(exceptionChannelPrice));
    }

    @PostMapping("/getOrderExceptionChannelPriceByItemId")
    @ApiOperation("根据订单ID,商品ID和异常ID获取价格")
    public CommonResult<OrderExceptionChannelPriceBackVO> getExceptionChannelPrice(@Valid @RequestBody OrderExceptionChannelPriceQueryVO queryVO) {
        LambdaQueryWrapper<OrderExceptionChannelPriceDO> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(OrderExceptionChannelPriceDO::getOrderId, queryVO.getOrderId());
        queryWrapper.eq(OrderExceptionChannelPriceDO::getOrderItemId, queryVO.getOrderItemId());
        queryWrapper.eq(OrderExceptionChannelPriceDO::getExceptionId, queryVO.getExceptionId());
        OrderExceptionChannelPriceDO exceptionChannelPrice = exceptionChannelPriceService.getOne(queryWrapper);
        return success(OrderExceptionChannelPriceConvert.INSTANCE.convert(exceptionChannelPrice));
    }

    /*
     getOrderExceptionChannelPriceList
     */
    @PostMapping("/getOrderExceptionChannelPriceList")
    @ApiOperation("根据订单ID,异常ID获取价格")
    public CommonResult<List<OrderExceptionChannelPriceBackVO>> getOrderExceptionChannelPriceList(@Valid @RequestBody OrderExceptionChannelPriceQueryVO queryVO) {
        LambdaQueryWrapper<OrderExceptionChannelPriceDO> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(OrderExceptionChannelPriceDO::getOrderId, queryVO.getOrderId());
        queryWrapper.eq(OrderExceptionChannelPriceDO::getExceptionId, queryVO.getExceptionId());
        queryWrapper.eq(OrderExceptionChannelPriceDO::getExceptionResultId, queryVO.getExceptionResultId());
        List<OrderExceptionChannelPriceDO> exceptionChannelPrice =
                exceptionChannelPriceService.list(queryWrapper);
        return success(OrderExceptionChannelPriceConvert.INSTANCE.convertList(exceptionChannelPrice));
    }


}
