package cn.iocoder.yudao.module.order.controller.admin.orderExceptionResult;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.order.convert.orderExceptionResult.OrderExceptionResultConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.orderExceptionResult.OrderExceptionResultDO;
import cn.iocoder.yudao.module.order.service.orderExceptionResult.OrderExceptionResultService;
import cn.iocoder.yudao.module.order.vo.orderExceptionResult.OrderExceptionResultBackVO;
import cn.iocoder.yudao.module.order.vo.orderExceptionResult.OrderExceptionResultCreateReqVO;
import cn.iocoder.yudao.module.order.vo.orderExceptionResult.OrderExceptionResultQueryVO;
import cn.iocoder.yudao.module.order.vo.orderExceptionResult.OrderExceptionResultUpdateReqVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

@Validated
@RestController
@Api(tags = "管理后台 - 异常处理记录")
@RequestMapping("/ecw/order-exception-result")
public class OrderExceptionResultController {

    @Resource
    private OrderExceptionResultService orderExceptionResultService;

    @PostMapping("/create")
    @ApiOperation("创建异常处理记录")
    public CommonResult<Long> createOrderExceptionResult(@Valid @RequestBody OrderExceptionResultCreateReqVO createReqVO) {
        return success(orderExceptionResultService.createOrderExceptionResult(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新异常处理记录")
    public CommonResult<Boolean> updateOrderExceptionResult(@Valid @RequestBody OrderExceptionResultUpdateReqVO updateReqVO) {
        orderExceptionResultService.updateOrderExceptionResult(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除异常处理记录")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteOrderExceptionResult(@RequestParam("id") Long id) {
        orderExceptionResultService.deleteOrderExceptionResult(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得异常处理记录")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderExceptionResultBackVO> getOrderExceptionResult(@RequestParam("id") Long id) {
        OrderExceptionResultDO orderExceptionResult = orderExceptionResultService.getOrderExceptionResult(id);
        return success(OrderExceptionResultConvert.INSTANCE.convert(orderExceptionResult));
    }

    @GetMapping("/list")
    @ApiOperation("获得异常处理记录列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "[1024,2048]", dataTypeClass = List.class)
    public CommonResult<List<OrderExceptionResultBackVO>> getOrderExceptionResultList(@RequestParam("ids") Collection<Long> ids) {
        List<OrderExceptionResultDO> list = orderExceptionResultService.getOrderExceptionResultList(ids);
        return success(OrderExceptionResultConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得异常处理记录分页")
    public CommonResult<PageResult<OrderExceptionResultBackVO>> getOrderExceptionResultPage(@Valid OrderExceptionResultQueryVO query, PageVO page) {
        PageResult<OrderExceptionResultDO> pageResult = orderExceptionResultService.getOrderExceptionResultPage(query, page);
        return success(OrderExceptionResultConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出异常处理记录 Excel")
    @OperateLog(type = EXPORT)
    public void exportOrderExceptionResultExcel(@Valid OrderExceptionResultQueryVO query,
                                                HttpServletResponse response) throws IOException {
        List<OrderExceptionResultDO> list = orderExceptionResultService.getOrderExceptionResultList(query);
        // 导出 Excel
        List<OrderExceptionResultBackVO> datas = OrderExceptionResultConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "异常处理记录.xls", "数据", OrderExceptionResultBackVO.class, datas);
    }
}
