package cn.iocoder.yudao.module.order.controller.admin.orderExceptionResult.orderException;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.LocalDateTimeUtil;
import cn.hutool.core.util.StrUtil;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.i18n.core.I18nMessage;
import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.order.convert.orderException.OrderExceptionConvert;
import cn.iocoder.yudao.module.order.convert.orderItem.OrderItemConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.orderException.OrderExceptionDO;
import cn.iocoder.yudao.module.order.dal.dataobject.orderExceptionResult.OrderExceptionResultDO;
import cn.iocoder.yudao.module.order.dal.dataobject.orderItem.OrderItemDO;
import cn.iocoder.yudao.module.order.service.order.OrderItemService;
import cn.iocoder.yudao.module.order.service.order.OrderQueryService;
import cn.iocoder.yudao.module.order.service.orderException.OrderExceptionService;
import cn.iocoder.yudao.module.order.service.orderExceptionResult.OrderExceptionResultService;
import cn.iocoder.yudao.module.order.vo.order.StatisticsOrderVO;
import cn.iocoder.yudao.module.order.vo.orderException.*;
import cn.iocoder.yudao.module.order.vo.orderItem.OrderItemBackVO;
import cn.iocoder.yudao.module.system.api.file.FileMakeApi;
import cn.iocoder.yudao.module.system.api.file.dto.FileMakeReqDTO;
import cn.iocoder.yudao.module.system.enums.download.DownloadTypeEnum;
import com.alibaba.fastjson.JSONObject;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

@Validated
@RestController
@Api(tags = "管理后台 - 订单异常")
@RequestMapping("/ecw/order-exception")
@Slf4j
public class OrderExceptionController {

    @Resource
    private OrderExceptionService orderExceptionService;
    @Resource
    private OrderItemService orderItemService;
    @Resource
    private OrderQueryService orderQueryService;

    @Resource
    private OrderExceptionResultService orderExceptionResultService;
    @Resource
    private FileMakeApi fileMakeApi;

    @GetMapping("/page")
    @ApiOperation("获得订单异常分页")
    public CommonResult<PageResult<OrderBackVO>> getOrderExceptionPage(
            @Valid OrderExceptionQueryVO query, PageVO page) {

        if (StrUtil.isNotBlank(query.getSalesmanId())) {
            //得到跟进客服对应的所有客户经理
            List<String> serviceIdList =
                    orderExceptionService.getCustomerServiceListById(
                            Long.parseLong(query.getSalesmanId()));
            if(CollectionUtil.isEmpty(serviceIdList)){
                serviceIdList = new ArrayList<>();
                // 避免因为查询条件为空不执行，这里对没有对应客户经理的跟进客服，进行非空参数添加，以保证不能获取数据的查询条件执行
                serviceIdList.add("-1");
            }
            List<String> customerServiceList = query.getCustomerIds();
            if (null == customerServiceList) {
                customerServiceList = new ArrayList<>();
            }
            customerServiceList.addAll(serviceIdList);
            List list = customerServiceList.stream().distinct().
                    collect(Collectors.toList());
            query.setCustomerIds(list);
        }
        PageResult<OrderBackVO> pageResult =
                orderExceptionService.selectOrderExceptionPage(query, page);
        return success(pageResult);
    }


    @GetMapping("/statistics")
    @ApiOperation("参数查询获得订单统计")
    public CommonResult<StatisticsOrderVO> statisticsDeptOrder(OrderExceptionQueryVO query) {
        if (StrUtil.isNotBlank(query.getSalesmanId())) {
            //得到跟进客服对应的所有客户经理
            List<String> serviceIdList = orderExceptionService.getCustomerServiceListById(Long.parseLong(query.getSalesmanId()));
            List<String> customerServiceList = query.getCustomerIds();
            if (null == customerServiceList) {
                customerServiceList = new ArrayList<>();
            }
            customerServiceList.addAll(serviceIdList);
            List list = customerServiceList.stream().distinct().collect(Collectors.toList());
            query.setCustomerIds(list);
        }


        return success(orderExceptionService.statisticsOrder(query));
    }

    /*
     根据订单ID获取订单异常处理记录
     */
    @GetMapping("/getExceptionListByOrderId")
    @ApiOperation("根据订单ID获取所有的订单异常列表")
    @ApiImplicitParam(name = "orderId", value = "订单ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<List<OrderExceptionBackVO>> getOrderExceptionListByOrderId(@RequestParam("orderId") Long orderId) {
        List<OrderExceptionBackVO> list =
                orderExceptionService.getOrderExceptionListByOrderId(orderId);
        for (OrderExceptionBackVO v : list
        ) {
            // 处理少箱异常，创建时间和处理时间一致
            if (v.getHandlerRemark() != null
                    && v.getOrderExceptionType() != null) {
                if (v.getHandlerRemark().equals("系统自动处理 处理人admin") &&
                        v.getOrderExceptionType() == "order_lack_box_exception") {
                    //少箱异常
                    v.setHandlerTime(v.getCreateTime());
                }
            }
        }
        return success(list);
    }

    @GetMapping("/getExceptionById")
    @ApiOperation("根据ID获得异常")
    @ApiImplicitParam(name = "id", value = "id", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderExceptionBackVO> getOrderException(@RequestParam("id") Long id) {
        OrderExceptionDO orderException = orderExceptionService.getOrderException(id);
        return success(OrderExceptionConvert.INSTANCE.convert(orderException));
    }


    @PostMapping("/handlerExceptionByExceptionId")
    @ApiOperation("根据异常ID进行异常处理")
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> handlerExceptionByExceptionId(@Validated @RequestBody OrderExceptionResultHandlerVo orderExceptionResultHandlerVo) {
        orderExceptionResultHandlerVo.setSource("pc");
        orderExceptionService.handlerExceptionByExceptionId(orderExceptionResultHandlerVo);
        return success(true);
    }

    @GetMapping("/getOrderItemById")
    @ApiOperation("根据订单商品ID获得订单商品")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderItemBackVO> getOrderItem(@RequestParam("id") Long id) {
        OrderItemDO orderItem = orderItemService.getOrderItem(id);
        return success(OrderItemConvert.INSTANCE.convert(orderItem));
    }

    @GetMapping("/getOrderFeeById")
    @ApiOperation("根据订单ID获取所有费用及比例")
    @ApiImplicitParam(name = "id", value = "订单ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderFeeDetailBackVO> getOrderFeeById(@RequestParam("id") Long id) {
        return success(orderQueryService.getOrderFeeDetailById(id));
    }

    @GetMapping("/cancelBpmByExceptionId")
    @ApiOperation("根据异常ID取消正在审核中的流程")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "订单ID", required = true, example = "1024", dataTypeClass = Long.class), @ApiImplicitParam(name = "remark", value = "取消原因", required = true, example = "不想要了", dataTypeClass = String.class)})
    public CommonResult<Boolean> cancelBpmByExceptionId(@RequestParam("id") Long id, @RequestParam("remark") String remark) {
        orderExceptionService.cancelBpmByExceptionId(id, remark);
        return success(true);
    }

    @GetMapping("/getBmpDetailByBusinessId")
    @ApiOperation("根据工作流中传的业务ID,获取异常审核详情")
    @ApiImplicitParam(name = "businessId", value = "工作流中传的业务ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderFeeDetailBackVO> getBmpDetailByBusinessId(@RequestParam("businessId") Long id) {
        OrderExceptionDO exceptionDo = orderExceptionService.getOrderException(id);
        OrderFeeDetailBackVO vo = orderQueryService.getOrderFeeDetailById(exceptionDo.getOrderId());
        if (StringUtils.isNotBlank(exceptionDo.getOrderExceptionNotes())) {
            vo.setNotes(exceptionDo.getOrderExceptionNotes());
        }
        return success(vo);
    }

    @GetMapping("/getExceptionDetailByBusinessId")
    @ApiOperation("根据工作流中传的业务ID,获取不可出渠道异常详细信息")
    @ApiImplicitParam(name = "businessId", value = "工作流中传的业务ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderExceptionBackVO> getExceptionDetailByBusinessId(@RequestParam("businessId") Long id) {
        OrderExceptionResultDO resultDO = orderExceptionResultService.getById(id);
        OrderExceptionDO orderExceptionDO = orderExceptionService.getById(resultDO.getOrderExceptionId());
        OrderExceptionBackVO backVO = OrderExceptionConvert.INSTANCE.convert(orderExceptionDO);
        backVO.setApplyNotes(resultDO.getHandlerRemark());
        return success(backVO);
    }


    /* @GetMapping("/get")
        @ApiOperation("获得订单异常")
        @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
            public CommonResult<OrderExceptionBackVO> getOrderException(@RequestParam("id") Long id) {
            OrderExceptionDO orderException = orderExceptionService.getOrderException(id);
            return success(OrderExceptionConvert.INSTANCE.convert(orderException));
        }
        @PostMapping("/create")
        @ApiOperation("创建订单异常")
            public CommonResult<Long> createOrderException(@Valid @RequestBody OrderExceptionCreateReqVO createReqVO) {
            return success(orderExceptionService.createOrderException(createReqVO));
        }

        @PutMapping("/update")
        @ApiOperation("更新订单异常")
            public CommonResult<Boolean> updateOrderException(@Valid @RequestBody OrderExceptionUpdateReqVO updateReqVO) {
            orderExceptionService.updateOrderException(updateReqVO);
            return success(true);
        }

        @DeleteMapping("/delete")
        @ApiOperation("删除订单异常")
        @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
            public CommonResult<Boolean> deleteOrderException(@RequestParam("id") Long id) {
            orderExceptionService.deleteOrderException(id);
            return success(true);
        }
     */

    @GetMapping("/export-excel")
    @ApiOperation("导出订单异常 Excel")
    @OperateLog(type = EXPORT)
    public void exportOrderExceptionExcel(@Valid OrderExceptionQueryVO query, HttpServletResponse response) throws IOException {
        log.error("导出执行时间开始:{}", LocalDateTimeUtil.now());
        if (StrUtil.isNotBlank(query.getSalesmanId())) {
            //得到跟进客服对应的所有客户经理
            List<String> serviceIdList = orderExceptionService.getCustomerServiceListById(Long.parseLong(query.getSalesmanId()));
            List<String> customerServiceList = query.getCustomerIds();
            if (null == customerServiceList) {
                customerServiceList = new ArrayList<>();
            }
            customerServiceList.addAll(serviceIdList);
            List list = customerServiceList.stream().distinct().collect(Collectors.toList());
            query.setCustomerIds(list);
        }
        List<OrderExceptionExcelVO> list = orderExceptionService.getOrderExceptionExcelList(query);
        log.error("导出执行时间结束:{}", LocalDateTimeUtil.now());
        ExcelUtils.write(response, "订单异常.xls", "数据", OrderExceptionExcelVO.class, list);
    }


    @GetMapping("/export-excel-async")
    @ApiOperation("异步导出订单异常 Excel")
    @OperateLog(type = EXPORT)
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> exportOrderExceptionExcel(@Valid OrderExceptionQueryVO query) {
        FileMakeReqDTO reqDTO = new FileMakeReqDTO();
        reqDTO.setType(DownloadTypeEnum.EXCEPTION_ORDER_EXCEL_EXPORT.getType());
        reqDTO.setName("异常订单导出Excel");
        reqDTO.setFileSuffix("xlsx");
        reqDTO.setTemporaryFile(true);
        reqDTO.setUserType(2);
        reqDTO.setLang(I18nMessage.getLang());
        reqDTO.setRequestParams(JSONObject.toJSONString(query));
        fileMakeApi.sendFileMake(reqDTO);
        return success(true);
    }


}
