package cn.iocoder.yudao.module.order.controller.admin.orderFeeApplication;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.framework.redis.helper.RedisHelper;
import cn.iocoder.yudao.module.order.convert.orderFeeApplication.OrderFeeApplicationConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.approval.OrderApprovalDO;
import cn.iocoder.yudao.module.order.dal.dataobject.order.OrderDO;
import cn.iocoder.yudao.module.order.dal.dataobject.orderFeeApplication.OrderFeeApplicationDO;
import cn.iocoder.yudao.module.order.enums.ApprovalResultStatusEnum;
import cn.iocoder.yudao.module.order.service.approval.OrderApprovalService;
import cn.iocoder.yudao.module.order.service.order.OrderFeeApplicationService;
import cn.iocoder.yudao.module.order.service.order.OrderService;
import cn.iocoder.yudao.module.order.vo.orderFeeApplication.OrderFeeApplicationBackVO;
import cn.iocoder.yudao.module.order.vo.orderFeeApplication.OrderFeeApplicationQueryVO;
import cn.iocoder.yudao.module.order.vo.orderFeeApplication.OrderFeeApplicationUpdateReqVO;
import cn.iocoder.yudao.module.order.vo.orderFeeApplication.OrderFeeBatchApplicationCreateReqVO;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.text.MessageFormat;
import java.util.Collection;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.error;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.module.order.enums.ErrorCodeConstants.*;

@Validated
@RestController
@Api(tags = "管理后台 - 订单费用申请")
@RequestMapping("/order/fee-application")
public class OrderFeeApplicationController {

    @Resource
    private OrderFeeApplicationService feeApplicationService;

    @Resource
    private OrderService orderService;

    @Resource
    private OrderApprovalService orderApprovalService;
    @Resource
    private RedisHelper redisHelper;

    /**
     * 订单费用申请操作的防重复提交缓存key
     */
    private static final String ORDER_FEE_APPLICATION_KEY = "jiedao:order:fee:application:{0}";

   /* @PostMapping("/create")
    @ApiOperation("创建订单费用申请")
    public CommonResult<Long> createFeeApplication(@Valid @RequestBody OrderFeeApplicationCreateReqVO createReqVO) throws Exception {
        if (!Objects.isNull(createReqVO)) {
            OrderDO orderDO = orderService.getById(createReqVO.getOrderId());
            if (orderDO.getAuditType() != 0) {
                throw exception(ORDER_HAS_PROCESSING_APPROVAL, orderDO.getOrderNo());
            }
        }
        Long feeApplication = 0L;
        try {
            feeApplication = feeApplicationService.createFeeApplication(createReqVO);
        } catch (ServiceException e){
            return error(e.getCode(),e.getMessage());
        }
        return success(feeApplication);
    }*/

    @PostMapping("/create/batch")
    @ApiOperation("批量创建订单费用申请")
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> createFeeBatchApplication(@Valid @RequestBody OrderFeeBatchApplicationCreateReqVO createReqVO) throws Exception {
        String redisKey = MessageFormat.format(ORDER_FEE_APPLICATION_KEY, createReqVO.getOrderId().toString());
        Long count = redisHelper.incrBy(redisKey, 1);
        if (count > 1){
            return error(ORDER_FEE_APPLICATION_REPEAT_COMMIT);
        }
        redisHelper.expire(redisKey, 1, TimeUnit.MINUTES);
        OrderDO orderDO = orderService.getById(createReqVO.getOrderId());
        if (orderDO.getAuditType() != 0) {
            throw exception(ORDER_HAS_PROCESSING_APPROVAL, orderDO.getOrderNo());
        }
        feeApplicationService.createFeeBatchApplication(createReqVO);
        redisHelper.delete(redisKey);
        return success(true);
    }

    @GetMapping("/get/batch")
    @ApiOperation("根据流程业务主键ID获得批量费用申请详细信息")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderApprovalDO> getOrderFeeApproval(@RequestParam("id") Long id) {
        return success(orderApprovalService.getApproval(id));
    }

    @GetMapping("/get/isApprove")
    @ApiOperation("根据订单ID获取是否有正在申请的费用申请,返回申请对象")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderApprovalDO> getApprovalByOrderId(@RequestParam("id") Long id) {
        LambdaQueryWrapper<OrderApprovalDO> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(OrderApprovalDO::getOrderId, id);
        lambdaQueryWrapper.eq(OrderApprovalDO::getStatus, ApprovalResultStatusEnum.processing.getValue());
        lambdaQueryWrapper.eq(OrderApprovalDO::getType, 41);
        return success(orderApprovalService.getOne(lambdaQueryWrapper));
    }


    @PutMapping("/update")
    @ApiOperation("更新订单费用申请")
    public CommonResult<Boolean> updateFeeApplication(@Valid @RequestBody OrderFeeApplicationUpdateReqVO updateReqVO) {
        if (!Objects.isNull(updateReqVO)) {
            OrderDO orderDO = orderService.getById(updateReqVO.getOrderId());
            if (orderDO.getAuditType() != 0) {
                throw exception(ORDER_HAS_PROCESSING_APPROVAL, orderDO.getOrderNo());
            }
        }
        feeApplicationService.updateFeeApplication(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/cancel")
    @ApiOperation("取消订单费用申请")
    public CommonResult<Boolean> cancelFeeApplication(@RequestBody OrderFeeApplicationUpdateReqVO orderFeeApplicationUpdateReqVO) {
        feeApplicationService.cancelFeeApplication(orderFeeApplicationUpdateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除订单费用申请")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteFeeApplication(@RequestParam("id") Long id) {
        feeApplicationService.deleteFeeApplication(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得订单费用申请")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderFeeApplicationBackVO> getFeeApplication(@RequestParam("id") Long id) {
        OrderFeeApplicationDO feeApplication = feeApplicationService.getFeeApplication(id);
        return success(OrderFeeApplicationConvert.INSTANCE.convert(feeApplication));
    }

    @GetMapping("/getOrderByProcessId")
    @ApiOperation("根据流程ID获得订单信息")
    @ApiImplicitParam(name = "processId", value = "流程编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderFeeApplicationBackVO> getOrderByProcessId(@RequestParam("processId") String processId) {
        OrderFeeApplicationBackVO vo = feeApplicationService.getOrderByProcessId(processId);
        return success(vo);
    }

    @GetMapping("/getBatchFeeByBusinessId")
    @ApiOperation("根据流程业务主键ID得到批量申请费用明细")
    @ApiImplicitParam(name = "businessId", value = "流程业务主键", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<List<OrderFeeApplicationBackVO>> getBatchFeeByProcessId(@RequestParam("businessId") String processId) {
        List<OrderFeeApplicationBackVO> vo = feeApplicationService.getBatchFeeByProcessId(processId);
        return success(vo);
    }

    @GetMapping("/list")
    @ApiOperation("获得订单费用申请列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<OrderFeeApplicationBackVO>> getFeeApplicationList(@RequestParam("ids") Collection<Long> ids) {
        List<OrderFeeApplicationDO> list = feeApplicationService.getFeeApplicationList(ids);
        return success(OrderFeeApplicationConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/listByOrderId")
    @ApiOperation("根据订单号获得订单费用申请列表")
    @ApiImplicitParam(name = "orderId", value = "订单编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<List<OrderFeeApplicationBackVO>> getFeeApplicationListByOrderId(@RequestParam("orderId") Long orderId) {
        List<OrderFeeApplicationDO> list = feeApplicationService.getFeeApplicationListByOrderId(orderId);
        return success(OrderFeeApplicationConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得订单费用申请分页")
    public CommonResult<PageResult<OrderFeeApplicationBackVO>> getFeeApplicationPage(@Valid OrderFeeApplicationQueryVO query, PageVO page) {
        PageResult<OrderFeeApplicationDO> pageResult = feeApplicationService.getFeeApplicationPage(query, page);
        return success(OrderFeeApplicationConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出订单费用申请 Excel")
    @OperateLog(type = EXPORT)
    public void exportFeeApplicationExcel(@Valid OrderFeeApplicationQueryVO query,
                                          HttpServletResponse response) throws IOException {
        List<OrderFeeApplicationDO> list = feeApplicationService.getFeeApplicationList(query);
        // 导出 Excel
        List<OrderFeeApplicationBackVO> datas = OrderFeeApplicationConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "订单费用申请.xls", "数据", OrderFeeApplicationBackVO.class, datas);
    }
}
