package cn.iocoder.yudao.module.order.controller.admin.orderGuanlian;

import cn.iocoder.yudao.framework.common.exception.ServiceException;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.convert.order.OrderConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.order.OrderDO;
import cn.iocoder.yudao.module.order.vo.order.OrderBackVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import java.util.stream.Collectors;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.error;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.order.vo.orderGuanlian.*;
import cn.iocoder.yudao.module.order.dal.dataobject.orderGuanlian.OrderGuanlianDO;
import cn.iocoder.yudao.module.order.convert.orderGuanlian.OrderGuanlianConvert;
import cn.iocoder.yudao.module.order.service.order.OrderGuanlianService;

@Validated
@RestController
@Api(tags = "管理后台 - 订单关联")
@RequestMapping("/order/guanlian")
public class OrderGuanlianController {

    @Resource
    private OrderGuanlianService guanlianService;

    @PostMapping("/create")
    @ApiOperation("创建订单关联")
    public CommonResult<Long> createGuanlian(@Valid @RequestBody OrderGuanlianCreateReqVO createReqVO) {
        return success(guanlianService.createGuanlian(createReqVO));
    }

    @PostMapping("/createBatch")
    @ApiOperation("批量创建订单关联")
    public CommonResult<Boolean> batchCreateGuanlian(@Valid @RequestBody List<OrderGuanlianCreateReqVO> createReqVOList) {
        guanlianService.batchCreateGuanlian(createReqVOList);
        return success(true);
    }

    @PutMapping("/update")
    @ApiOperation("更新订单关联")
    public CommonResult<Boolean> updateGuanlian(@Valid @RequestBody OrderGuanlianUpdateReqVO updateReqVO) {
        guanlianService.updateGuanlian(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除订单关联")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteGuanlian(@RequestParam("id") Long id) {
        guanlianService.deleteGuanlian(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得订单关联")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderGuanlianBackVO> getGuanlian(@RequestParam("id") Long id) {
        OrderGuanlianDO guanlian = guanlianService.getGuanlian(id);
        return success(OrderGuanlianConvert.INSTANCE.convert(guanlian));
    }

    @PostMapping("/getGuanlianOrderByOrderId")
    @ApiOperation("获得订单关联的订单信息")
    public CommonResult<PageResult<OrderGuanlianBackVO>> getGuanlianOrderByOrderId(@RequestBody OrderGuanlianQueryVO orderGuanlianQueryVO) {
        try {
            PageParam pageParam = new PageParam();
            pageParam.setPageNo(orderGuanlianQueryVO.getPage());
            pageParam.setPageSize(orderGuanlianQueryVO.getRows());
            PageResult<OrderGuanlianBackVO> pageGuanlianVO = guanlianService.getGuanlianOrderByOrderId(orderGuanlianQueryVO, pageParam);
            return success(pageGuanlianVO);
        } catch (ServiceException e) {
            return error(e.getCode(),e.getMessage());
        }
    }

    @DeleteMapping("/deleteGuanlianOrderByOrderId")
    @ApiOperation("删除订单关联")
    public CommonResult<Boolean> deleteGuanlianOrderByOrderId(@RequestBody OrderGuanlianQueryVO orderGuanlianQueryVO) {
        guanlianService.deleteGuanlianOrderByOrderId(orderGuanlianQueryVO);
        return success(true);
    }

    @DeleteMapping("/deleteBatchGuanlianOrderByOrderId")
    @ApiOperation("批量删除订单关联")
    public CommonResult<Boolean> deleteBatchGuanlianOrderByOrderId(@RequestBody List<OrderGuanlianQueryVO> orderGuanlianQueryVOList) {
        guanlianService.deleteBatchGuanlianOrderByOrderId(orderGuanlianQueryVOList);
        return success(true);
    }

    @PostMapping("/getUnGuanlianOrderByOrderId")
    @ApiOperation("获得订单未关联的订单信息")
    public CommonResult<PageResult<OrderBackVO>> getUnGuanlianOrderByOrderId(@RequestBody OrderGuanlianQueryVO orderGuanlianQueryVO) {
        try {
            PageVO pageVO = new PageVO();
            pageVO.setPage(orderGuanlianQueryVO.getPage());
            pageVO.setRows(orderGuanlianQueryVO.getRows());
            PageResult<OrderBackVO> orderDOS = guanlianService.getUnGuanlianOrderByOrderId(orderGuanlianQueryVO,pageVO);
            return success(orderDOS);
        } catch (ServiceException e){
            return error(e.getCode(),e.getMessage());
        }
    }

    @GetMapping("/list")
    @ApiOperation("获得订单关联列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<OrderGuanlianBackVO>> getGuanlianList(@RequestParam("ids") Collection<Long> ids) {
        List<OrderGuanlianDO> list = guanlianService.getGuanlianList(ids);
        return success(OrderGuanlianConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得订单关联分页")
    public CommonResult<PageResult<OrderGuanlianBackVO>> getGuanlianPage(@Valid OrderGuanlianQueryVO query, PageVO page) {
        PageResult<OrderGuanlianDO> pageResult = guanlianService.getGuanlianPage(query, page);
        return success(OrderGuanlianConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出订单关联 Excel")
    @OperateLog(type = EXPORT)
    public void exportGuanlianExcel(@Valid OrderGuanlianQueryVO query,
              HttpServletResponse response) throws IOException {
        List<OrderGuanlianDO> list = guanlianService.getGuanlianList(query);
        // 导出 Excel
        List<OrderGuanlianBackVO> datas = OrderGuanlianConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "订单关联.xls", "数据", OrderGuanlianBackVO.class, datas);
    }

    @GetMapping("/getRelateOrderListByOrderId")
    @ApiOperation("获得订单关联列表")
    @ApiImplicitParam(name = "orderId", value = "订单ID", required = true, example = "1", dataTypeClass = Long.class)
    public CommonResult<List<OrderBackVO>> getRelateOrderListByOrderId(@RequestParam("orderId") Long orderId) {
        List<OrderDO> list = guanlianService.getRelateOrderListByOrderId(orderId);
        return success(OrderConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/getAllRelateOrderList")
    @ApiOperation("获得订单所有关联列表")
    @ApiImplicitParam(name = "orderId", value = "订单ID", required = true, example = "1", dataTypeClass = Long.class)
    public CommonResult<OrderTree> getAllRelateOrderList(@RequestParam("orderId") Long orderId, @RequestParam("orderNo") String orderNo) {
        OrderTree orderTree = guanlianService.getAllRelateOrderList(orderId, orderNo);
        return success(orderTree, orderTree == null ? "" : orderTree.toString());
    }

    @GetMapping("/test")
    public CommonResult<String> test(@RequestParam("orderId") Long orderId, @RequestParam("orderIds") String orderIds) {
        String[] split = orderIds.split(",");
        List<String> strings = Arrays.asList(split);
        List<Long> collect = strings.stream().map(item -> Long.valueOf(item)).collect(Collectors.toList());
        guanlianService.dealGuanlianByOrderId(orderId,collect,2);
        return success("");
    }
}
