package cn.iocoder.yudao.module.order.controller.admin.orderLocation;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.module.order.convert.orderLocation.OrderLocationConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.orderLocation.OrderLocationDO;
import cn.iocoder.yudao.module.order.service.order.OrderLocationService;
import cn.iocoder.yudao.module.order.vo.orderLocation.OrderLocationBackVO;
import cn.iocoder.yudao.module.order.vo.orderLocation.OrderLocationUpdateReqSummaryVO;
import cn.iocoder.yudao.module.order.vo.orderLocation.OrderLocationUpdateReqVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "管理后台 - 订单仓位")
@RequestMapping("/order/location")
public class OrderLocationController {

    @Resource
    private OrderLocationService locationService;

    @GetMapping("/list-by-order-id")
    @ApiOperation("根据订单id获得订单仓位列表")
    @ApiImplicitParam(name = "orderId", value = "订单id", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<List<OrderLocationBackVO>> getLocationListByOrderId(
            @RequestParam("orderId") Long orderId) {
        List<OrderLocationDO> list =
                locationService.getOrderLocationListByOrderId(orderId);
        return success(OrderLocationConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/list-by-warehouse-in-id")
    @ApiOperation("根据入仓纪录id获得仓位列表")
    @ApiImplicitParam(name = "warehouseInId", value = "入仓纪录id", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<List<OrderLocationBackVO>> getLocationListByWarehouseInId(@RequestParam("warehouseInId") Long warehouseInId) {
        List<OrderLocationDO> list = locationService.getOrderLocationListByWarehouseInId(warehouseInId);
        return success(OrderLocationConvert.INSTANCE.convertList(list));
    }


    @PutMapping("/update")
    @ApiOperation("修改储位-老的")
    public CommonResult<Boolean> update(@Valid @RequestBody OrderLocationUpdateReqVO updateReqVO) {
        // 校验存在
        locationService.updateOrderLocation(updateReqVO);
        return success(true);
    }

    @PutMapping("/update-warehouse-in-location")
    @ApiOperation("修改入仓纪录对应的储位-新的")
    public CommonResult<Boolean> updateNew(@Valid @RequestBody OrderLocationUpdateReqSummaryVO orderLocationUpdateReqSummaryVO) {
        // 校验存在
        locationService.updateWarehouseInLocation(orderLocationUpdateReqSummaryVO);
        return success(true);
    }

    // @PostMapping("/create")
    // @ApiOperation("创建订单仓位")
    // @PreAuthorize("@ss.hasPermission('order:location:create')")
    // public CommonResult<Long> createLocation(@Valid @RequestBody OrderLocationCreateReqVO createReqVO) {
    //     return success(locationService.createOrderLocation(createReqVO));
    // }
    //
    // @PutMapping("/update")
    // @ApiOperation("更新订单仓位")
    // @PreAuthorize("@ss.hasPermission('order:location:update')")
    // public CommonResult<Boolean> updateLocation(@Valid @RequestBody OrderLocationUpdateReqVO updateReqVO) {
    //     locationService.updateOrderLocation(updateReqVO);
    //     return success(true);
    // }
    //
    // @DeleteMapping("/delete")
    // @ApiOperation("删除订单仓位")
    // @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    // @PreAuthorize("@ss.hasPermission('order:location:delete')")
    // public CommonResult<Boolean> deleteLocation(@RequestParam("id") Long id) {
    //     locationService.deleteOrderLocation(id);
    //     return success(true);
    // }
    //
    // @GetMapping("/get")
    // @ApiOperation("获得订单仓位")
    // @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    // @PreAuthorize("@ss.hasPermission('order:location:query')")
    // public CommonResult<OrderLocationBackVO> getLocation(@RequestParam("id") Long id) {
    //     OrderLocationDO location = locationService.getOrderLocation(id);
    //     return success(OrderLocationConvert.INSTANCE.convert(location));
    // }
    //
    // @GetMapping("/list")
    // @ApiOperation("获得订单仓位列表")
    // @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    // @PreAuthorize("@ss.hasPermission('order:location:query')")
    // public CommonResult<List<OrderLocationBackVO>> getLocationList(@RequestParam("ids") Collection<Long> ids) {
    //     List<OrderLocationDO> list = locationService.getOrderLocationList(ids);
    //     return success(OrderLocationConvert.INSTANCE.convertList(list));
    // }

    // @GetMapping("/page")
    // @ApiOperation("获得订单仓位分页")
    // @PreAuthorize("@ss.hasPermission('order:location:query')")
    // public CommonResult<PageResult<OrderLocationBackVO>> getLocationPage(@Valid OrderLocationQueryVO query, PageVO page) {
    //     PageResult<OrderLocationDO> pageResult = locationService.getOrderLocationPage(query, page);
    //     return success(OrderLocationConvert.INSTANCE.convertPage(pageResult));
    // }
    //
    // @GetMapping("/export-excel")
    // @ApiOperation("导出订单仓位 Excel")
    // @PreAuthorize("@ss.hasPermission('order:location:export')")
    // @OperateLog(type = EXPORT)
    // public void exportLocationExcel(@Valid OrderLocationQueryVO query,
    //           HttpServletResponse response) throws IOException {
    //     List<OrderLocationDO> list = locationService.getOrderLocationList(query);
    //     // 导出 Excel
    //     List<OrderLocationBackVO> datas = OrderLocationConvert.INSTANCE.convertList(list);
    //     ExcelUtils.write(response, "订单仓位.xls", "数据", OrderLocationBackVO.class, datas);
    // }
}
