package cn.iocoder.yudao.module.order.controller.admin.orderMutual;

import cn.iocoder.yudao.framework.common.exception.ServiceException;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.vo.order.OrderBackVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.error;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.order.vo.orderMutual.*;
import cn.iocoder.yudao.module.order.dal.dataobject.orderMutual.OrderMutualDO;
import cn.iocoder.yudao.module.order.convert.orderMutual.OrderMutualConvert;
import cn.iocoder.yudao.module.order.service.order.OrderMutualService;

@Validated
@RestController
@Api(tags = "管理后台 - 订单互斥")
@RequestMapping("/order/mutual")
public class OrderMutualController {

    @Resource
    private OrderMutualService mutualService;

    @PostMapping("/create")
    @ApiOperation("创建订单互斥")
    public CommonResult<Long> createMutual(@Valid @RequestBody OrderMutualCreateReqVO createReqVO) {
        return success(mutualService.createMutual(createReqVO));
    }

    @PostMapping("/createBatch")
    @ApiOperation("批量创建订单互斥")
    public CommonResult<Boolean> batchCreateMutual(@Valid @RequestBody List<OrderMutualCreateReqVO> createReqVOList) {
        mutualService.batchCreateMutual(createReqVOList);
        return success(true);
    }

    @PutMapping("/update")
    @ApiOperation("更新订单互斥")
    public CommonResult<Boolean> updateMutual(@Valid @RequestBody OrderMutualUpdateReqVO updateReqVO) {
        mutualService.updateMutual(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除订单互斥")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteMutual(@RequestParam("id") Long id) {
        mutualService.deleteMutual(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得订单互斥")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderMutualBackVO> getMutual(@RequestParam("id") Long id) {
        OrderMutualDO mutual = mutualService.getMutual(id);
        return success(OrderMutualConvert.INSTANCE.convert(mutual));
    }

    @PostMapping("/getMutualOrderByOrderId")
    @ApiOperation("获得订单互斥的订单信息")
    public CommonResult<PageResult<OrderMutualBackVO>> getMutualOrderByOrderId(@RequestBody OrderMutualQueryVO orderMutualQueryVO) {
        try {
            PageVO pageVO = new PageVO();
            pageVO.setPage(orderMutualQueryVO.getPage());
            pageVO.setRows(orderMutualQueryVO.getRows());
            PageResult<OrderMutualBackVO> orderDOS = mutualService.getMutualOrderByOrderId(orderMutualQueryVO,pageVO);
            return success(orderDOS);
        } catch (ServiceException e){
            return error(e.getCode(),e.getMessage());
        }
    }

    @DeleteMapping("/deleteMutualOrderByOrderId")
    @ApiOperation("根据订单和互斥订单ID删除订单互斥")
    public CommonResult<Boolean> deleteMutualOrderByOrderId(@RequestBody OrderMutualQueryVO orderMutualQueryVO) {
        mutualService.deleteMutualOrderByOrderId(orderMutualQueryVO);
        return success(true);
    }

    @DeleteMapping("/deleteBatchMutualOrderByOrderId")
    @ApiOperation("批量删除订单互斥")
    public CommonResult<Boolean> deleteBatchMutualOrderByOrderId(@RequestBody List<OrderMutualQueryVO> orderMutualQueryVOList) {
        mutualService.deleteBatchMutualOrderByOrderId(orderMutualQueryVOList);
        return success(true);
    }

    @PostMapping("/getUnMutualOrderByOrderId")
    @ApiOperation("获得订单未关联的订单信息")
    public CommonResult<PageResult<OrderBackVO>> getUnMutualOrderByOrderId(@RequestBody OrderMutualQueryVO orderMutualQueryVO) {
        try {
            PageVO pageVO = new PageVO();
            pageVO.setPage(orderMutualQueryVO.getPage());
            pageVO.setRows(orderMutualQueryVO.getRows());
            PageResult<OrderBackVO> orderDOS = mutualService.getUnMutualOrderByOrderId(orderMutualQueryVO,pageVO);
            return success(orderDOS);
        } catch (ServiceException e){
            return error(e.getCode(),e.getMessage());
        }
    }

    @GetMapping("/list")
    @ApiOperation("获得订单互斥列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<OrderMutualBackVO>> getMutualList(@RequestParam("ids") Collection<Long> ids) {
        List<OrderMutualDO> list = mutualService.getMutualList(ids);
        return success(OrderMutualConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得订单互斥分页")
    public CommonResult<PageResult<OrderMutualBackVO>> getMutualPage(@Valid OrderMutualQueryVO query, PageVO page) {
        PageResult<OrderMutualDO> pageResult = mutualService.getMutualPage(query, page);
        return success(OrderMutualConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出订单互斥 Excel")
    @OperateLog(type = EXPORT)
    public void exportMutualExcel(@Valid OrderMutualQueryVO query,
              HttpServletResponse response) throws IOException {
        List<OrderMutualDO> list = mutualService.getMutualList(query);
        // 导出 Excel
        List<OrderMutualBackVO> datas = OrderMutualConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "订单互斥.xls", "数据", OrderMutualBackVO.class, datas);
    }
}
