package cn.iocoder.yudao.module.order.controller.admin.orderOperateLog;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.order.vo.orderOperateLog.*;
import cn.iocoder.yudao.module.order.dal.dataobject.orderOperateLog.OrderOperateLogDO;
import cn.iocoder.yudao.module.order.convert.orderOperateLog.OrderOperateLogConvert;
import cn.iocoder.yudao.module.order.service.orderOperateLog.OrderOperateLogService;

@Validated
@RestController
@Api(tags = "管理后台 - 订单操作日志")
@RequestMapping("/ecw/order-operate-log")
public class OrderOperateLogController {

    @Resource
    private OrderOperateLogService orderOperateLogService;

    @GetMapping("/get")
    @ApiOperation("获得订单操作日志")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:order:logs')")
    public CommonResult<OrderOperateLogBackVO> getOrderOperateLog(@RequestParam("id") Long id) {
        OrderOperateLogDO orderOperateLog = orderOperateLogService.getOrderOperateLog(id);
        return success(OrderOperateLogConvert.INSTANCE.convert(orderOperateLog));
    }

    @GetMapping("/list")
    @ApiOperation("获得订单操作日志列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
//    @PreAuthorize("@ss.hasPermission('ecw:order:logs')")
    public CommonResult<List<OrderOperateLogPageBackVO>> getOrderOperateLogList(@RequestParam("ids") Collection<Long> ids) {
        List<OrderOperateLogDO> list = orderOperateLogService.getOrderOperateLogList(ids);
        return success(OrderOperateLogConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得订单操作日志分页")
//    @PreAuthorize("@ss.hasPermission('ecw:order:logs')")
    public CommonResult<PageResult<OrderOperateLogPageBackVO>> getOrderOperateLogPage(@Valid OrderOperateLogQueryVO query, PageVO page) {
        PageResult<OrderOperateLogDO> pageResult = orderOperateLogService.getOrderOperateLogPage(query, page);
        return success(OrderOperateLogConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出订单操作日志 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:order:logs:export')")
    @OperateLog(type = EXPORT)
    public void exportOrderOperateLogExcel(@Valid OrderOperateLogQueryVO query,
              HttpServletResponse response) throws IOException {
        List<OrderOperateLogDO> list = orderOperateLogService.getOrderOperateLogList(query);
        // 导出 Excel
        List<OrderOperateLogPageBackVO> datas = OrderOperateLogConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "订单操作日志.xls", "数据", OrderOperateLogPageBackVO.class, datas);
    }
}
