package cn.iocoder.yudao.module.order.controller.admin.orderSpecialNeed;

import cn.iocoder.yudao.framework.common.exception.ServiceException;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.error;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.order.vo.orderSpecialNeed.*;
import cn.iocoder.yudao.module.order.dal.dataobject.orderSpecialNeed.OrderSpecialNeedDO;
import cn.iocoder.yudao.module.order.convert.orderSpecialNeed.OrderSpecialNeedConvert;
import cn.iocoder.yudao.module.order.service.order.OrderSpecialNeedService;

@Validated
@RestController
@Api(tags = "管理后台 - 特需")
@RequestMapping("/ecw/order-special-need")
public class OrderSpecialNeedController {

    @Resource
    private OrderSpecialNeedService orderSpecialNeedService;

    @PostMapping("/create")
    @ApiOperation("创建特需")
    public CommonResult<Boolean> createOrderSpecialNeed(@Valid @RequestBody List<OrderSpecialNeedCreateReqVO> createReqVOList) {
        orderSpecialNeedService.createOrderSpecialNeed(createReqVOList);
        return success(true);
    }

    @PutMapping("/update")
    @ApiOperation("更新特需")
    public CommonResult<Boolean> updateOrderSpecialNeed(@Valid @RequestBody OrderSpecialNeedUpdateReqVO updateReqVO) {
        orderSpecialNeedService.updateOrderSpecialNeed(updateReqVO);
        return success(true);
    }

    @PutMapping("/updateBatch")
    @ApiOperation("批量更新特需")
    public CommonResult<Boolean> updateOrderSpecialNeedBatch(@RequestBody List<OrderSpecialNeedUpdateReqVO> updateReqVOList) throws Exception {
        try {
            orderSpecialNeedService.updateOrderSpecialNeedBatch(updateReqVOList);
            return success(true);
        } catch (ServiceException e) {
            return error(e.getCode(),e.getMessage());
        }
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除特需")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteOrderSpecialNeed(@RequestParam("id") Long id)  {
        orderSpecialNeedService.deleteOrderSpecialNeed(id);
        return success(true);
    }

    @DeleteMapping("/deleteByOrderId")
    @ApiOperation("根据订单ID删除特需")
    public CommonResult<Boolean> deleteByOrderId(@RequestBody OrderSpecialNeedQueryVO orderSpecialNeedQueryVO) {
        orderSpecialNeedService.deleteByOrderId(orderSpecialNeedQueryVO);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得特需")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderSpecialNeedBackVO> getOrderSpecialNeed(@RequestParam("id") Long id) {
        OrderSpecialNeedDO orderSpecialNeed = orderSpecialNeedService.getOrderSpecialNeed(id);
        return success(OrderSpecialNeedConvert.INSTANCE.convert(orderSpecialNeed));
    }

    @GetMapping("/getListByOrderId")
    @ApiOperation("根据订单ID获得特需列表")
    @ApiImplicitParam(name = "orderId", value = "订单ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<List<OrderSpecialNeedBackVO>> getListByOrderId(@RequestParam("orderId") Long orderId) {
        List<OrderSpecialNeedDO> list = orderSpecialNeedService.getListByOrderId(orderId);
        return success(OrderSpecialNeedConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/list")
    @ApiOperation("获得特需列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<OrderSpecialNeedBackVO>> getOrderSpecialNeedList(@RequestParam("ids") Collection<Long> ids) {
        List<OrderSpecialNeedDO> list = orderSpecialNeedService.getOrderSpecialNeedList(ids);
        return success(OrderSpecialNeedConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得特需分页")
    public CommonResult<PageResult<OrderSpecialNeedBackVO>> getOrderSpecialNeedPage(@Valid OrderSpecialNeedQueryVO query, PageVO page) {
        PageResult<OrderSpecialNeedDO> pageResult = orderSpecialNeedService.getOrderSpecialNeedPage(query, page);
        return success(OrderSpecialNeedConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出特需 Excel")
    @OperateLog(type = EXPORT)
    public void exportOrderSpecialNeedExcel(@Valid OrderSpecialNeedQueryVO query,
              HttpServletResponse response) throws IOException {
        List<OrderSpecialNeedDO> list = orderSpecialNeedService.getOrderSpecialNeedList(query);
        // 导出 Excel
        List<OrderSpecialNeedBackVO> datas = OrderSpecialNeedConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "特需.xls", "数据", OrderSpecialNeedBackVO.class, datas);
    }
}
