package cn.iocoder.yudao.module.order.controller.admin.orderSplit;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.module.order.convert.approval.OrderApprovalConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.approval.OrderApprovalDO;
import cn.iocoder.yudao.module.order.enums.OrderApprovalTypeEnum;
import cn.iocoder.yudao.module.order.service.approval.OrderApprovalService;
import cn.iocoder.yudao.module.order.service.orderSplit.OrderSplitService;
import cn.iocoder.yudao.module.order.vo.approval.OrderApprovalBackVO;
import cn.iocoder.yudao.module.order.vo.approval.OrderApprovalCancelApplyReqVO;
import cn.iocoder.yudao.module.order.vo.orderSplit.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "管理后台 - 订单拆单")
@RequestMapping("/order/split")
public class OrderSplitController {

    @Resource
    private OrderSplitService splitService;

    @Resource
    private OrderApprovalService orderApprovalService;


    @PostMapping("/create")
    @ApiOperation("新增拆单")
    public CommonResult<Boolean> create(@Valid @RequestBody OrderSplitCreateReqVO createReqVO) {
        return success(splitService.createSplit(createReqVO));
    }


    @GetMapping("/revoke/{orderId}")
    @ApiOperation("撤销拆单详情")
    @ApiImplicitParam(name = "orderId", value = "订单ID(可以是任意子订单或母订单id)", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderSplitRevokeApplyDetailDto> revokeSplitInfo(@PathVariable("orderId") Long orderId) {
        return success(splitService.revokeSplitInfo(orderId));
    }

    @GetMapping("/revoke/apply/{approvalId}")
    @ApiOperation("撤销拆单详情")
    @ApiImplicitParam(name = "approvalId", value = "审批业务ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderSplitRevokeApplyDetailDto> revokeSplitInfoByApprovalId(@PathVariable("approvalId") Long approvalId) {
        return success(splitService.revokeSplitInfoByApprovalId(approvalId));
    }

    @PutMapping("/revoke")
    @ApiOperation("撤销拆单")
    public CommonResult<Boolean> revoke(@RequestBody OrderSplitApplyReqVO applyReqVO) {
        return success(splitService.revoke(applyReqVO));
    }

    @PutMapping("cancel/revoke")
    @ApiOperation("取消撤销拆单")
    public CommonResult<Boolean> cancelRevoke(@RequestBody OrderApprovalCancelApplyReqVO cancelApplyReqVO) {
        return success(splitService.cancelRevoke(cancelApplyReqVO));
    }


    @DeleteMapping("/delete")
    @ApiOperation("删除拆单")
    @ApiImplicitParam(name = "id", value = "拆单编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> delete(@RequestParam("id") Long id) {
        return success(splitService.deleteSplit(id));
    }

    @DeleteMapping("/delete/all")
    @ApiOperation("重置拆单")
    @ApiImplicitParam(name = "orderId", value = "订单ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteAllSpilt(@RequestParam("orderId") Long orderId) {
        return success(splitService.deleteAllSplit(orderId));
    }

    @PutMapping("/apply")
    @ApiOperation("拆单申请提交")
    public CommonResult<Boolean> apply(@Valid @RequestBody OrderSplitApplyReqVO applyReqVO) {
        return success(splitService.splitApply(applyReqVO));
    }

    @GetMapping("/apply-callback")
    @ApiOperation("拆单申请回调-测试使用")
    public CommonResult<Boolean> applyCallback(String formId, Integer result) {
        splitService.splitApplyCallback(formId, result);
        return success(true);
    }

    @PutMapping("/cancel-apply")
    @ApiOperation("取消申请")
    public CommonResult<Boolean> calcenApply(@Valid @RequestBody OrderApprovalCancelApplyReqVO cancelApplyReqVO) {
        return success(splitService.cancelSplitApply(cancelApplyReqVO));
    }

    @GetMapping("/list-by-order-id")
    @ApiOperation("通过订单号获取拆单列表和拆单项明细")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "订单编号", required = true, example = "1024", dataTypeClass = Long.class),
            @ApiImplicitParam(name = "lang", value = "语言 0中文 1英文", required = true, example = "0", dataTypeClass = Integer.class)
    })
    public CommonResult<OrderSplitApprovalBackVO> listByOrderId(@RequestParam("orderId") Long orderId, @RequestParam("lang") Integer lang) {
        List<OrderSplitBackVO> list = splitService.listByOrderId(orderId, lang);

        OrderApprovalDO orderApprovalDO = orderApprovalService.getLast(orderId, OrderApprovalTypeEnum.ORDER_SPLIT);

        OrderApprovalBackVO orderApprovalBackVO = OrderApprovalConvert.INSTANCE.convert(orderApprovalDO);

        OrderSplitApprovalBackVO orderSplitApprovalBackVO = new OrderSplitApprovalBackVO();
        orderSplitApprovalBackVO.setOrderApprovalBackVO(orderApprovalBackVO);
        orderSplitApprovalBackVO.setOrderSplitBackVOList(list);
        return success(orderSplitApprovalBackVO);
    }


    // @PostMapping("/create")
    // @ApiOperation("创建订单拆单")
    // // public CommonResult<Long> createSplit(@Valid @RequestBody OrderSplitCreateReqVO createReqVO) {
    //     return success(splitService.createSplit(createReqVO));
    // }
    //
    // @PutMapping("/update")
    // @ApiOperation("更新订单拆单")
    // // public CommonResult<Boolean> updateSplit(@Valid @RequestBody OrderSplitUpdateReqVO updateReqVO) {
    //     splitService.updateSplit(updateReqVO);
    //     return success(true);
    // }
    //
    // @DeleteMapping("/delete")
    // @ApiOperation("删除订单拆单")
    // @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    // // public CommonResult<Boolean> deleteSplit(@RequestParam("id") Long id) {
    //     splitService.deleteSplit(id);
    //     return success(true);
    // }
    //
    // @GetMapping("/get")
    // @ApiOperation("获得订单拆单")
    // @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    // // public CommonResult<OrderSplitBackVO> getSplit(@RequestParam("id") Long id) {
    //     OrderSplitDO split = splitService.getSplit(id);
    //     return success(OrderSplitConvert.INSTANCE.convert(split));
    // }
    //
    // @GetMapping("/list")
    // @ApiOperation("获得订单拆单列表")
    // @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    // // public CommonResult<List<OrderSplitBackVO>> getSplitList(@RequestParam("ids") Collection<Long> ids) {
    //     List<OrderSplitDO> list = splitService.getSplitList(ids);
    //     return success(OrderSplitConvert.INSTANCE.convertList(list));
    // }
    //
    // @GetMapping("/page")
    // @ApiOperation("获得订单拆单分页")
    // // public CommonResult<PageResult<OrderSplitBackVO>> getSplitPage(@Valid OrderSplitQueryVO query, PageVO page) {
    //     PageResult<OrderSplitDO> pageResult = splitService.getSplitPage(query, page);
    //     return success(OrderSplitConvert.INSTANCE.convertPage(pageResult));
    // }
    //
    // @GetMapping("/export-excel")
    // @ApiOperation("导出订单拆单 Excel")
    // // @OperateLog(type = EXPORT)
    // public void exportSplitExcel(@Valid OrderSplitQueryVO query,
    //           HttpServletResponse response) throws IOException {
    //     List<OrderSplitDO> list = splitService.getSplitList(query);
    //     // 导出 Excel
    //     List<OrderSplitBackVO> datas = OrderSplitConvert.INSTANCE.convertList(list);
    //     ExcelUtils.write(response, "订单拆单.xls", "数据", OrderSplitBackVO.class, datas);
    // }
}
