package cn.iocoder.yudao.module.order.controller.admin.orderSplitItem;

import cn.iocoder.yudao.module.order.dto.OrderSplitWorthDto;
import cn.iocoder.yudao.module.order.service.orderSplit.OrderSplitCheckService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.*;

import javax.validation.*;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.module.order.vo.orderSplitItem.*;
import cn.iocoder.yudao.module.order.service.orderSplitItem.OrderSplitItemService;

@Validated
@RestController
@Api(tags = "管理后台 - 订单拆单项")
@RequestMapping("/order/split-item")
public class OrderSplitItemController {

    @Resource
    private OrderSplitItemService splitItemService;
    @Resource
    private OrderSplitCheckService orderSplitCheckService;


    @PostMapping("/create")
    @ApiOperation("创建订单拆单项 - 放入")
    public CommonResult<Boolean> putIn(@Valid @RequestBody OrderSplitItemCreateReqVO createReqVO) {
        return success(splitItemService.createSplitItem(createReqVO));
    }

    @PostMapping("/update")
    @ApiOperation(value = "修改订单拆单项 - 直接修改数值", notes = "允许单独修改某一个数值，空值或0，不予更新")
    public CommonResult<Boolean> update(@Valid @RequestBody OrderSplitItemUpdateReqVO updateReqVO) {
        return success(splitItemService.updateSplitItem(updateReqVO));
    }

    @GetMapping("/quantity/check")
    @ApiOperation("计价单位的数量参数是否必传")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "seaFreightVolume", value = "运费单位", required = true, example = "1024", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = "clearanceFreightVolume", value = "清关费单位", example = "1024", dataTypeClass = Integer.class)
    })
    public CommonResult<Boolean> quantityCheck(@RequestParam("seaFreightVolume") Integer seaFreightVolume, @RequestParam(value = "clearanceFreightVolume", required = false) Integer clearanceFreightVolume) {
        return success(splitItemService.checkItemVolume(seaFreightVolume, clearanceFreightVolume));
    }

    @GetMapping("/worth/check")
    @ApiOperation("拆单订单的总货值与箱数拆分记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "进行拆单的订单id", required = true, example = "1024", dataTypeClass = Long.class),
            @ApiImplicitParam(name = "orderSplitItemId", value = "拆单项id", example = "1024", dataTypeClass = Long.class)
    })

    public CommonResult<OrderSplitWorthDto> worthCheck(@RequestParam("orderId") Long orderId, @RequestParam(value = "orderSplitItemId", required = false) Long orderSplitItemId) {
        return success(orderSplitCheckService.getCheckOrderWorthDtoByOrderId(orderId, orderSplitItemId));
    }

    @PostMapping("/batchCreate")
    @ApiOperation("创建订单拆单项 - 批量放入")
    public CommonResult<Boolean> batchCreate(@Valid @RequestBody OrderSplitItemBatchCreateReqVO createReqVO) {
        return success(splitItemService.batchCreate(createReqVO));
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除订单拆单项 - 移除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class),
            @ApiImplicitParam(name = "shipmentSplit", value = "是否出货拆单", example = "true/false", dataTypeClass = Boolean.class)
    })

    public CommonResult<Boolean> deleteSplitItem(@RequestParam("id") Long id,
                                                 @RequestParam(value = "shipmentSplit", required = false, defaultValue = "false") Boolean shipmentSplit) {
        splitItemService.deleteSplitItem(id, shipmentSplit);
        return success(true);
    }


    // @PutMapping("/update")
    // @ApiOperation("更新订单拆单产品项")
    // // public CommonResult<Boolean> updateSplitItem(@Valid @RequestBody OrderSplitItemUpdateReqVO updateReqVO) {
    //     splitItemService.updateSplitItem(updateReqVO);
    //     return success(true);
    // }
    //
    // @GetMapping("/get")
    // @ApiOperation("获得订单拆单产品项")
    // @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    // // public CommonResult<OrderSplitItemBackVO> getSplitItem(@RequestParam("id") Long id) {
    //     OrderSplitItemDO splitItem = splitItemService.getSplitItem(id);
    //     return success(OrderSplitItemConvert.INSTANCE.convert(splitItem));
    // }
    //
    // @GetMapping("/list")
    // @ApiOperation("获得订单拆单产品项列表")
    // @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    // // public CommonResult<List<OrderSplitItemBackVO>> getSplitItemList(@RequestParam("ids") Collection<Long> ids) {
    //     List<OrderSplitItemDO> list = splitItemService.getSplitItemList(ids);
    //     return success(OrderSplitItemConvert.INSTANCE.convertList(list));
    // }
    //
    // @GetMapping("/page")
    // @ApiOperation("获得订单拆单产品项分页")
    // // public CommonResult<PageResult<OrderSplitItemBackVO>> getSplitItemPage(@Valid OrderSplitItemQueryVO query, PageVO page) {
    //     PageResult<OrderSplitItemDO> pageResult = splitItemService.getSplitItemPage(query, page);
    //     return success(OrderSplitItemConvert.INSTANCE.convertPage(pageResult));
    // }
    //
    // @GetMapping("/export-excel")
    // @ApiOperation("导出订单拆单产品项 Excel")
    // // @OperateLog(type = EXPORT)
    // public void exportSplitItemExcel(@Valid OrderSplitItemQueryVO query,
    //           HttpServletResponse response) throws IOException {
    //     List<OrderSplitItemDO> list = splitItemService.getSplitItemList(query);
    //     // 导出 Excel
    //     List<OrderSplitItemBackVO> datas = OrderSplitItemConvert.INSTANCE.convertList(list);
    //     ExcelUtils.write(response, "订单拆单产品项.xls", "数据", OrderSplitItemBackVO.class, datas);
    // }
}
