package cn.iocoder.yudao.module.order.controller.admin.orderTime;

import cn.iocoder.yudao.module.order.dal.dataobject.order.OrderDO;
import cn.iocoder.yudao.module.order.service.order.OrderService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import java.util.*;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.error;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.module.order.enums.ErrorCodeConstants.ORDER_NO_NOT_NULL;

import cn.iocoder.yudao.module.order.vo.orderTime.*;
import cn.iocoder.yudao.module.order.dal.dataobject.orderTime.OrderTimeDO;
import cn.iocoder.yudao.module.order.convert.orderTime.OrderTimeConvert;
import cn.iocoder.yudao.module.order.service.order.OrderTimeService;

@Validated
@RestController
@Api(tags = "管理后台 - 下单时间轴事件")
@RequestMapping("/ecw/order-time")
public class OrderTimeController {

    @Autowired
    private OrderTimeService orderTimeService;
    @Autowired
    private OrderService orderService;


    @GetMapping("/list")
    @ApiOperation("获得订单物流信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "订单ID", example = "1024", dataTypeClass = Long.class),
            @ApiImplicitParam(name = "orderNo", value = "订单编号", example = "NA2200001F", dataTypeClass = String.class)
    })
    public CommonResult<List<OrderTimeBackVO>> getOrderTimeList(@RequestParam(value = "orderId", required = false) Long orderId,
                                                                @RequestParam(value = "orderNo", required = false) String orderNo) {
       if (Objects.isNull(orderId) && StringUtils.isBlank(orderNo)){
           return error(ORDER_NO_NOT_NULL);
       }
       if (Objects.isNull(orderId)){
           OrderDO orderDO = orderService.getOne(new LambdaQueryWrapper<OrderDO>().eq(OrderDO::getOrderNo, orderNo).last("limit 1"));
           if (Objects.isNull(orderDO)){
               return success(Collections.emptyList());
           }
           orderId = orderDO.getOrderId();
       }
        List<OrderTimeDO> list = orderTimeService.getOrderTimeList(orderId);
        return success(OrderTimeConvert.INSTANCE.convertList(list));
    }


}
