package cn.iocoder.yudao.module.order.controller.admin.orderWarehouseApproval;

import cn.hutool.core.collection.CollectionUtil;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.order.convert.orderWarehouseApproval.OrderWarehouseApprovalConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.orderWarehouseAdjust.OrderWarehouseAdjustDO;
import cn.iocoder.yudao.module.order.dal.dataobject.orderWarehouseApproval.OrderWarehouseApprovalDO;
import cn.iocoder.yudao.module.order.enums.OrderWarehouseApprovalTypeEnum;
import cn.iocoder.yudao.module.order.service.orderWarehouseAdjust.OrderWarehouseAdjustService;
import cn.iocoder.yudao.module.order.service.orderWarehouseApproval.OrderWarehouseApprovalService;
import cn.iocoder.yudao.module.order.vo.orderWarehouseApproval.OrderWarehouseApprovalBackVO;
import cn.iocoder.yudao.module.order.vo.orderWarehouseApproval.OrderWarehouseApprovalQueryVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.Arrays;
import java.util.Collection;
import java.util.List;
import java.util.stream.Collectors;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

@Validated
@RestController
@Api(tags = "管理后台 - 入仓单审核")
@RequestMapping("/order/order-warehouse-approval")
public class OrderWarehouseApprovalController {

    @Resource
    private OrderWarehouseApprovalService orderWarehouseApprovalService;

    @Resource
    private OrderWarehouseAdjustService orderWarehouseAdjustService;

    //@PostMapping("/create")
    //@ApiOperation("创建入仓单审核")
    ////public CommonResult<Long> createOrderWarehouseApproval(@Valid @RequestBody OrderWarehouseApprovalCreateReqVO createReqVO) {
    //    return success(orderWarehouseApprovalService.createOrderWarehouseApproval(createReqVO));
    //}

    //@PutMapping("/update")
    //@ApiOperation("更新入仓单审核")
    ////public CommonResult<Boolean> updateOrderWarehouseApproval(@Valid @RequestBody OrderWarehouseApprovalUpdateReqVO updateReqVO) {
    //    orderWarehouseApprovalService.updateOrderWarehouseApproval(updateReqVO);
    //    return success(true);
    //}

    //@DeleteMapping("/delete")
    //@ApiOperation("删除入仓单审核")
    //@ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    ////public CommonResult<Boolean> deleteOrderWarehouseApproval(@RequestParam("id") Long id) {
    //    orderWarehouseApprovalService.deleteOrderWarehouseApproval(id);
    //    return success(true);
    //}

    @GetMapping("/get-by-id")
    @ApiOperation("根据审核ID获得仓库审核单详情")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderWarehouseApprovalBackVO> getOrderWarehouseApprovalById(@RequestParam("id") Long id) {
        OrderWarehouseApprovalDO orderWarehouseApproval = orderWarehouseApprovalService.getOrderWarehouseApproval(id);
        OrderWarehouseApprovalBackVO convert = OrderWarehouseApprovalConvert.INSTANCE.convert(orderWarehouseApproval);

        setAdjustActualOrderIds(orderWarehouseApproval, convert);

        return success(convert);
    }

    private void setAdjustActualOrderIds(OrderWarehouseApprovalDO orderWarehouseApproval, OrderWarehouseApprovalBackVO convert) {
        if (OrderWarehouseApprovalTypeEnum.WAREHOUSE_IN_TRANSFER.getValue().equals(orderWarehouseApproval.getType())) {
            List<Long> adjustIds = Arrays.stream(convert.getOrderIds().split(",")).map(Long::parseLong).collect(Collectors.toList());
            List<OrderWarehouseAdjustDO> warehouseAdjustList = orderWarehouseAdjustService.getWarehouseAdjustList(adjustIds);
            if (CollectionUtil.isNotEmpty(warehouseAdjustList)) {
                String actualOrderIds = warehouseAdjustList.stream().map(orderWarehouseAdjustDO -> orderWarehouseAdjustDO.getOrderId().toString()).collect(Collectors.joining(","));

                convert.setAdjustActualOrderIds(actualOrderIds);
            }
        }
    }

    @GetMapping("/get-by-form-id")
    @ApiOperation("通过bpmFormId 获得仓库审核单详情")
    @ApiImplicitParam(name = "formId", value = "bpm表单id", required = true, dataTypeClass = String.class)
    public CommonResult<OrderWarehouseApprovalBackVO> getOrderWarehouseApprovalInfoByBpmFormId(@RequestParam("formId") String formId) {
        OrderWarehouseApprovalDO orderWarehouseApproval = orderWarehouseApprovalService.getOrderWarehouseApproval(formId);
        OrderWarehouseApprovalBackVO convert = OrderWarehouseApprovalConvert.INSTANCE.convert(orderWarehouseApproval);
        setAdjustActualOrderIds(orderWarehouseApproval, convert);
        return success(convert);
    }



    @GetMapping("cancel/{approvalId}")
    @ApiOperation("根据审批id取消审批")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "approvalId", value = "审批ID", required = true, example = "1024", dataType = "Long"),
            @ApiImplicitParam(name = "reason", value = "取消原因", required = true, example = "1024", dataType = "String")
    })
    public CommonResult<Boolean> cancelOrderWarehouseApproval(@PathVariable(value = "approvalId") Long orderApprovalId,
                                                              @RequestParam(value = "reason", required = false) String reason) {
        orderWarehouseApprovalService.cancelOrderWarehouseApproval(orderApprovalId, reason);
        return success(Boolean.TRUE);
    }

    @GetMapping("/list")
    @ApiOperation("获得入仓单审核列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<OrderWarehouseApprovalBackVO>> getOrderWarehouseApprovalList(@RequestParam("ids") Collection<Long> ids) {
        List<OrderWarehouseApprovalDO> list = orderWarehouseApprovalService.getOrderWarehouseApprovalList(ids);
        return success(OrderWarehouseApprovalConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得入仓单审核分页")
    public CommonResult<PageResult<OrderWarehouseApprovalBackVO>> getOrderWarehouseApprovalPage(@Valid OrderWarehouseApprovalQueryVO query, PageVO page) {
        PageResult<OrderWarehouseApprovalDO> pageResult = orderWarehouseApprovalService.getOrderWarehouseApprovalPage(query, page);
        return success(OrderWarehouseApprovalConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出入仓单审核 Excel")
    @OperateLog(type = EXPORT)
    public void exportOrderWarehouseApprovalExcel(@Valid OrderWarehouseApprovalQueryVO query,
                                                  HttpServletResponse response) throws IOException {
        List<OrderWarehouseApprovalDO> list = orderWarehouseApprovalService.getOrderWarehouseApprovalList(query);
        // 导出 Excel
        List<OrderWarehouseApprovalBackVO> datas = OrderWarehouseApprovalConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "入仓单审核.xls", "数据", OrderWarehouseApprovalBackVO.class, datas);
    }
}
