package cn.iocoder.yudao.module.order.controller.admin.orderWarehousePicture;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.order.vo.orderWarehousePicture.*;
import cn.iocoder.yudao.module.order.dal.dataobject.orderWarehousePicture.OrderWarehousePictureDO;
import cn.iocoder.yudao.module.order.convert.orderWarehousePicture.OrderWarehousePictureConvert;
import cn.iocoder.yudao.module.order.service.orderWarehousePicture.OrderWarehousePictureService;

@Validated
@RestController
@Api(tags = "管理后台 - 订单仓库图片")
@RequestMapping("/order/warehouse-picture")
public class OrderWarehousePictureController {

    @Resource
    private OrderWarehousePictureService warehousePictureService;


    @PostMapping("/list")
    @ApiOperation("获得订单入仓/调仓/转异/报关资料等的图片列表")
    public CommonResult<List<OrderWarehousePictureBackVO>> getWarehousePictureList(@Valid @RequestBody OrderWarehousePictureQueryVO orderWarehousePictureQueryVO) {
        List<OrderWarehousePictureDO> list = warehousePictureService.getWarehousePictureList(orderWarehousePictureQueryVO);
        return success(OrderWarehousePictureConvert.INSTANCE.convertList(list));
    }


    @PostMapping("/create")
    @ApiOperation("上传图片")
    public CommonResult<Long> createWarehousePicture(@Valid @RequestBody OrderWarehousePictureCreateReqVO createReqVO) {
        return success(warehousePictureService.createWarehousePicture(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新订单仓库图片")
    public CommonResult<Boolean> updateWarehousePicture(@Valid @RequestBody OrderWarehousePictureUpdateReqVO updateReqVO) {
        warehousePictureService.updateWarehousePicture(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除订单仓库图片")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteWarehousePicture(@RequestParam("id") Long id) {
        warehousePictureService.deleteWarehousePicture(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得订单仓库图片")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderWarehousePictureBackVO> getWarehousePicture(@RequestParam("id") Long id) {
        OrderWarehousePictureDO warehousePicture = warehousePictureService.getWarehousePicture(id);
        return success(OrderWarehousePictureConvert.INSTANCE.convert(warehousePicture));
    }

    // @GetMapping("/list")
    // @ApiOperation("获得订单仓库图片列表")
    // @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    // public CommonResult<List<OrderWarehousePictureBackVO>> getWarehousePictureList(@RequestParam("ids") Collection<Long> ids) {
    //     List<OrderWarehousePictureDO> list = warehousePictureService.getWarehousePictureList(ids);
    //     return success(OrderWarehousePictureConvert.INSTANCE.convertList(list));
    // }

    @GetMapping("/page")
    @ApiOperation("获得订单仓库图片分页")
    public CommonResult<PageResult<OrderWarehousePictureBackVO>> getWarehousePicturePage(@Valid OrderWarehousePictureQueryVO query, PageVO page) {
        PageResult<OrderWarehousePictureDO> pageResult = warehousePictureService.getWarehousePicturePage(query, page);
        return success(OrderWarehousePictureConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出订单仓库图片 Excel")
    @OperateLog(type = EXPORT)
    public void exportWarehousePictureExcel(@Valid OrderWarehousePictureQueryVO query,
              HttpServletResponse response) throws IOException {
        List<OrderWarehousePictureDO> list = warehousePictureService.getWarehousePictureList(query);
        // 导出 Excel
        List<OrderWarehousePictureBackVO> datas = OrderWarehousePictureConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "订单仓库图片.xls", "数据", OrderWarehousePictureBackVO.class, datas);
    }
}
