package cn.iocoder.yudao.module.order.controller.admin.pda;

import cn.hutool.core.collection.CollectionUtil;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import cn.iocoder.yudao.module.depository.dal.dataobject.warehouse.DeptWarehouseDO;
import cn.iocoder.yudao.module.depository.service.warehouse.WarehouseService;
import cn.iocoder.yudao.module.depository.vo.dept.DeptWarehouseBaseVO;
import cn.iocoder.yudao.module.order.convert.orderWarehousePicture.OrderWarehousePictureConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.orderWarehousePicture.OrderWarehousePictureDO;
import cn.iocoder.yudao.module.order.enums.OrderStatusEnum;
import cn.iocoder.yudao.module.order.enums.OrderWarehouseInStatusEnum;
import cn.iocoder.yudao.module.order.service.order.OrderQueryService;
import cn.iocoder.yudao.module.order.service.orderWarehousePicture.OrderWarehousePictureService;
import cn.iocoder.yudao.module.order.vo.order.OrderBackPageVO;
import cn.iocoder.yudao.module.order.vo.order.PdaOrderQueryVo;
import cn.iocoder.yudao.module.order.vo.orderWarehousePicture.OrderWarehousePictureBackVO;
import cn.iocoder.yudao.module.order.vo.orderWarehousePicture.OrderWarehousePictureQueryVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import jodd.util.StringUtil;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "管理后台 -  PDA订单相关接口")
@RequestMapping("/order/pda")
public class PdaOrderController {

    @Resource
    private OrderQueryService orderQueryService;

    @Resource
    private WarehouseService warehouseService;

    @Resource
    private OrderWarehousePictureService warehousePictureService;

    @GetMapping("/warehouse-wait-in")
    @ApiOperation("pad-待入仓列表")
    public CommonResult<PageResult<OrderBackPageVO>> pdaWarehouseInPage(String orderNo, PageVO page) {

        PdaOrderQueryVo queryVO = new PdaOrderQueryVo();
        String pdaWarehouseIds = getPdaUserWarehouseIds();
        //设置始发仓
        queryVO.setPdaStartWareIds(pdaWarehouseIds);

        //待入仓列表默认显示等待入仓的订单列表，但可以搜索已入仓未出仓的订单
        if (StringUtil.isNotEmpty(orderNo)) {
            queryVO.setOrderNo(orderNo.contains("-") ? orderNo.substring(0, orderNo.lastIndexOf("-")) : orderNo);
            // queryVO.setStatusList(Arrays.asList(OrderStatusEnum.IN_WAREHOUSE.getValue()));
            queryVO.setExcludeStatusList(Arrays.asList(OrderStatusEnum.DRAFT.getValue(), OrderStatusEnum.CANCEL.getValue()));
        } else {
            //状态包含：已下单，入仓中，已退仓
            queryVO.setStatusList(Arrays.asList(OrderStatusEnum.ORDER_PLACED.getValue(),
                    OrderStatusEnum.WAREHOUSING.getValue(), OrderStatusEnum.WITHDRAWN.getValue()));
        }

        //添加查询状态: 1海运拼柜, 2海运整柜, 4海空联运
        queryVO.setTransportIdList(CollectionUtil.newArrayList(1, 2, 4));

        PageResult<OrderBackPageVO> pageResult = orderQueryService.pdaOrderWarehouseInPage(queryVO, page);
        return success(pageResult);
    }

    @GetMapping("/air-warehouse-wait-in")
    @ApiOperation("pad-空运待入仓列表")
    public CommonResult<PageResult<OrderBackPageVO>> pdaAirWarehouseInPage(String orderNo, PageVO page) {

        PdaOrderQueryVo queryVO = new PdaOrderQueryVo();
        String pdaWarehouseIds = getPdaUserWarehouseIds();
        //设置始发仓
        queryVO.setPdaStartWareIds(pdaWarehouseIds);

        //待入仓列表默认显示等待入仓的订单列表，但可以搜索已入仓未出仓的订单
        if (StringUtil.isNotEmpty(orderNo)) {
            queryVO.setOrderNo(orderNo.contains("-") ? orderNo.substring(0, orderNo.lastIndexOf("-")) : orderNo);
            // queryVO.setStatusList(Arrays.asList(OrderStatusEnum.IN_WAREHOUSE.getValue()));
            queryVO.setExcludeStatusList(Arrays.asList(OrderStatusEnum.DRAFT.getValue(), OrderStatusEnum.CANCEL.getValue()));
        } else {
            //状态包含：已下单，入仓中，已退仓
            queryVO.setStatusList(Arrays.asList(OrderStatusEnum.ORDER_PLACED.getValue(),
                    OrderStatusEnum.WAREHOUSING.getValue(), OrderStatusEnum.WITHDRAWN.getValue()));
        }

        //添加查询状态: 空运专线
        queryVO.setTransportIdList(CollectionUtil.newArrayList(3));

        PageResult<OrderBackPageVO> pageResult = orderQueryService.pdaOrderWarehouseInPage(queryVO, page);
        return success(pageResult);
    }

    @GetMapping("/adjust/wait-out")
    @ApiOperation("pda-调仓待出仓列表")
    public CommonResult<PageResult<OrderBackPageVO>> pdaWarehouseAdjustWaitOut(String orderNo, PageVO page) {

        PdaOrderQueryVo queryVO = new PdaOrderQueryVo();
        String pdaUserWarehouseIds = getPdaUserWarehouseIds();
        queryVO.setPdaAdjustStartWareIds(pdaUserWarehouseIds);

        //待入仓列表默认显示等待入仓的订单列表，但可以搜索任意状态下的订单
        if (StringUtil.isNotEmpty(orderNo)) {
            queryVO.setOrderNo(orderNo.contains("-") ? orderNo.substring(0, orderNo.lastIndexOf("-")) : orderNo);
            queryVO.setExcludeStatusList(Arrays.asList(OrderStatusEnum.DRAFT.getValue()));
        }
        //调仓中
        queryVO.setStatus(OrderStatusEnum.WAREHOUSE_ADJUSTMENT.getValue());
        //调仓待入仓
        queryVO.setWarehouseInStatus(OrderWarehouseInStatusEnum.adjust_wait_out.getValue());

        PageResult<OrderBackPageVO> pageResult = orderQueryService.pdaOrderWarehouseAdjustWaitOut(queryVO, page);
        return success(pageResult);
    }

    @GetMapping("/adjust/wait-in")
    @ApiOperation("pda-调仓待入仓列表")
    public CommonResult<PageResult<OrderBackPageVO>> pdaWarehouseAdjustWaitIn(String orderNo, PageVO page) {

        PdaOrderQueryVo queryVO = new PdaOrderQueryVo();
        String pdaUserWarehouseIds = getPdaUserWarehouseIds();
        queryVO.setPdaAdjustDestWareIds(pdaUserWarehouseIds);

        //待入仓列表默认显示等待入仓的订单列表，但可以搜索任意状态下的订单
        if (StringUtil.isNotEmpty(orderNo)) {
            queryVO.setOrderNo(orderNo.contains("-") ? orderNo.substring(0, orderNo.lastIndexOf("-")) : orderNo);
            queryVO.setExcludeStatusList(Arrays.asList(OrderStatusEnum.DRAFT.getValue()));
        }
        //调仓中
        queryVO.setStatus(OrderStatusEnum.WAREHOUSE_ADJUSTMENT.getValue());
        //调仓待入仓
        queryVO.setWarehouseInStatus(OrderWarehouseInStatusEnum.adjust_wait_in.getValue());

        PageResult<OrderBackPageVO> pageResult = orderQueryService.pdaOrderWarehouseAdjustWaitOut(queryVO, page);
        return success(pageResult);
    }


    private String getPdaUserWarehouseIds() {
        //获取当前用户部门所管理的仓库列表
        Long deptId = SecurityFrameworkUtils.getLoginUser().getDeptId();

        //获取仓库id列表
        DeptWarehouseBaseVO deptWarehouseBaseVO = new DeptWarehouseBaseVO();
        deptWarehouseBaseVO.setDeptId(deptId);
        List<DeptWarehouseDO> deptWarehouseDOS = warehouseService.deptList(deptWarehouseBaseVO);
        if (CollectionUtil.isNotEmpty(deptWarehouseDOS)) {
            String warehouseIds = deptWarehouseDOS.stream().filter(t -> Boolean.FALSE.equals(t.getDeleted()) && t.getWarehouseId() != null)
                    .map(t -> t.getWarehouseId().toString())
                    .collect(Collectors.joining(","));
            //仓库id, 提供给订单查询接口
            return warehouseIds;
        }
        return null;
    }


    @PostMapping("/picture/list")
    @ApiOperation("获得订单入仓/调仓/转异/订单项/报关相关的仓库影像列表")
    public CommonResult<List<OrderWarehousePictureBackVO>> getWarehousePictureList(@Valid @RequestBody OrderWarehousePictureQueryVO orderWarehousePictureQueryVO) {
        List<OrderWarehousePictureDO> list = warehousePictureService.getWarehousePictureList(orderWarehousePictureQueryVO);
        return success(OrderWarehousePictureConvert.INSTANCE.convertList(list));
    }

}
