package cn.iocoder.yudao.module.order.controller.app.orderCargoControlPick;

import cn.hutool.core.collection.CollectionUtil;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;
import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import cn.iocoder.yudao.module.member.dal.dataobject.user.MemberUserDO;
import cn.iocoder.yudao.module.member.service.user.MemberUserService;
import cn.iocoder.yudao.module.order.dal.dataobject.orderCargoControl.OrderCargoControlDO;
import cn.iocoder.yudao.module.order.dal.dataobject.orderCargoControlPick.OrderCargoControlPickDO;
import cn.iocoder.yudao.module.order.dto.OrderCargoControlReleaseInfoDto;
import cn.iocoder.yudao.module.order.service.orderCargoControl.OrderCargoControlService;
import cn.iocoder.yudao.module.order.service.orderCargoControlPick.OrderCargoControlPickService;
import cn.iocoder.yudao.module.order.vo.orderCargoControlPick.OrderCargoControlPickApplyVO;
import cn.iocoder.yudao.module.order.vo.orderCargoControlPick.OrderCargoControlPickCreateReqVO;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.module.order.enums.ErrorCodeConstants.*;

@Validated
@RestController
@Api(tags = "app-web - 订单控货人放货记录")
@RequestMapping("/order/order-cargo-control-pick")
public class AppOrderCargoControlPickController {

    @Resource
    private OrderCargoControlPickService orderCargoControlPickService;
    @Resource
    private OrderCargoControlService orderCargoControlService;
    @Resource
    private MemberUserService memberUserService;

    @PostMapping("/create")
    @ApiOperation("创建订单控货人放货记录")
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Long> createOrderCargoControlPick(@Valid @RequestBody OrderCargoControlPickCreateReqVO createReqVO) {
        return success(orderCargoControlPickService.createOrderCargoControlPick(createReqVO));
    }

    @PutMapping("/review/{id}")
    @ApiOperation("复合订单控货人放货")
    @ApiImplicitParam(name = "id", value = "放货记录ID", required = true, example = "1024", dataType = "Long")
    @PreAuthenticated
    public CommonResult<Boolean> reviewOrderCargoControlPick(@PathVariable("id") Long id) {
        OrderCargoControlPickDO orderCargoControlPickDO = orderCargoControlPickService.getById(id);
        if (Objects.isNull(orderCargoControlPickDO)) {
            throw exception(ORDER_CARGO_CONTROL_PICK_NOT_EXISTS);
        }
        OrderCargoControlDO orderCargoControlDO = orderCargoControlService.getOne(new LambdaQueryWrapper<OrderCargoControlDO>()
                .eq(OrderCargoControlDO::getOrderId, orderCargoControlPickDO.getOrderId())
                .eq(OrderCargoControlDO::getIsActual, Boolean.TRUE)
                .orderByDesc(OrderCargoControlDO::getId).last("limit 1"));
        if (Objects.isNull(orderCargoControlDO)) {
            throw exception(ORDER_CARGO_CONTROL_NOT_EXISTS);
        }
        MemberUserDO memberUserDO = memberUserService.getUser(SecurityFrameworkUtils.getLoginUserId());
        if (!Objects.equals(orderCargoControlDO.getPhone(), memberUserDO.getMobile())) {
            throw exception(YOU_NO_IS_CARGO_CONTROLLER);
        }
        orderCargoControlPickService.reviewOrderCargoControlPick(orderCargoControlPickDO);
        return success(Boolean.TRUE);
    }


    @PutMapping("/anti-checking")
    @ApiOperation("反复合订单控货人放货")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "订单ID(批量处理)",  example = "1024", dataType = "Long"),
            @ApiImplicitParam(name = "id", value = "放货记录ID",  example = "1024", dataType = "Long")
    })
    @PreAuthenticated
    public CommonResult<Boolean> antiCheckingOrderCargoControlPick(Long orderId, Long id) {
        List<OrderCargoControlPickDO> allOrderCargoControlPickDOList = new ArrayList<>();
        if (Objects.nonNull(orderId) && orderId > 0){
            OrderCargoControlDO orderCargoControlDO = orderCargoControlService.getOne(new LambdaQueryWrapper<OrderCargoControlDO>()
                    .eq(OrderCargoControlDO::getOrderId, orderId)
                    .eq(OrderCargoControlDO::getIsActual, Boolean.TRUE)
                    .orderByDesc(OrderCargoControlDO::getId).last("limit 1"));
            if (Objects.isNull(orderCargoControlDO)) {
                throw exception(ORDER_CARGO_CONTROL_NOT_EXISTS);
            }
            MemberUserDO memberUserDO = memberUserService.getUser(SecurityFrameworkUtils.getLoginUserId());
            if (!Objects.equals(orderCargoControlDO.getPhone(), memberUserDO.getMobile())) {
                throw exception(YOU_NO_IS_CARGO_CONTROLLER);
            }

            List<OrderCargoControlPickDO> orderCargoControlPickDOList = orderCargoControlPickService.list(new LambdaQueryWrapper<OrderCargoControlPickDO>()
                    .eq(OrderCargoControlPickDO::getOrderId, orderId)
                    .eq(OrderCargoControlPickDO::getStatus, 3)
                    .eq(OrderCargoControlPickDO::getDeleted, Boolean.FALSE)
            );
            if (CollectionUtil.isEmpty(orderCargoControlPickDOList)) {
                throw exception(ORDER_CARGO_CONTROL_PICK_NOT_EXISTS);
            }
            allOrderCargoControlPickDOList.addAll(orderCargoControlPickDOList);
        }else {
            OrderCargoControlPickDO orderCargoControlPickDO = orderCargoControlPickService.getById(id);
            if (Objects.isNull(orderCargoControlPickDO)) {
                throw exception(ORDER_CARGO_CONTROL_PICK_NOT_EXISTS);
            }
            orderId = orderCargoControlPickDO.getOrderId();
            OrderCargoControlDO orderCargoControlDO = orderCargoControlService.getOne(new LambdaQueryWrapper<OrderCargoControlDO>()
                    .eq(OrderCargoControlDO::getOrderId, orderCargoControlPickDO.getOrderId())
                    .eq(OrderCargoControlDO::getIsActual, Boolean.TRUE)
                    .orderByDesc(OrderCargoControlDO::getId).last("limit 1"));
            if (Objects.isNull(orderCargoControlDO)) {
                throw exception(ORDER_CARGO_CONTROL_NOT_EXISTS);
            }
            MemberUserDO memberUserDO = memberUserService.getUser(SecurityFrameworkUtils.getLoginUserId());
            if (!Objects.equals(orderCargoControlDO.getPhone(), memberUserDO.getMobile())) {
                throw exception(YOU_NO_IS_CARGO_CONTROLLER);
            }
            allOrderCargoControlPickDOList.add(orderCargoControlPickDO);
        }
        orderCargoControlPickService.batchAntiCheckingOrderCargoControlPick(allOrderCargoControlPickDOList, orderId, 1);
        return success(Boolean.TRUE);
    }

    @PutMapping("/cancel/{id}")
    @ApiOperation("订单控货人取消放货")
    @ApiImplicitParam(name = "id", value = "放货记录ID", required = true, example = "1024", dataType = "Long")
    @PreAuthenticated
    public CommonResult<Boolean> cancelOrderCargoControlPick(@PathVariable("id") Long id) {
        OrderCargoControlPickDO orderCargoControlPickDO = orderCargoControlPickService.getById(id);
        if (Objects.isNull(orderCargoControlPickDO)) {
            throw exception(ORDER_CARGO_CONTROL_PICK_NOT_EXISTS);
        }
        OrderCargoControlDO orderCargoControlDO = orderCargoControlService.getOne(new LambdaQueryWrapper<OrderCargoControlDO>()
                .eq(OrderCargoControlDO::getOrderId, orderCargoControlPickDO.getOrderId())
                .eq(OrderCargoControlDO::getIsActual, Boolean.TRUE)
                .orderByDesc(OrderCargoControlDO::getId).last("limit 1"));
        if (Objects.isNull(orderCargoControlDO)) {
            throw exception(ORDER_CARGO_CONTROL_NOT_EXISTS);
        }
        MemberUserDO memberUserDO = memberUserService.getUser(SecurityFrameworkUtils.getLoginUserId());
        if (!Objects.equals(orderCargoControlDO.getPhone(), memberUserDO.getMobile())) {
            throw exception(YOU_NO_IS_CARGO_CONTROLLER);
        }
        orderCargoControlPickService.cancelOrderCargoControlPick(orderCargoControlPickDO);
        return success(Boolean.TRUE);
    }


    @GetMapping("/release/info/{orderId}")
    @ApiOperation("获得控货订单放货详情")
    @ApiImplicitParam(name = "orderId", value = "订单ID", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<OrderCargoControlReleaseInfoDto> getOrderCargoControlReleaseInfo(@PathVariable("orderId") Long orderId) {
        OrderCargoControlReleaseInfoDto releaseInfoDto = orderCargoControlPickService.getOrderCargoControlReleaseInfo(orderId);
        return success(releaseInfoDto);
    }


    @PutMapping("/update/apply")
    @ApiOperation("放货修改与反复核申请")
    @PreAuthenticated
    public CommonResult<Boolean> orderCargoControlPickApply(@Valid @RequestBody OrderCargoControlPickApplyVO orderCargoControlPickApplyVO) {
        orderCargoControlPickService.orderCargoControlPickApply(orderCargoControlPickApplyVO);
        return success(true);
    }

    @GetMapping("update/info")
    @ApiOperation("获得控货订单放货修改申请详情")
    @ApiImplicitParam(name = "approveId", value = "审核ID", required = true, example = "1024", dataType = "Long")
    @PreAuthenticated
    public CommonResult<OrderCargoControlPickApplyVO> approvalOrderCargoControlPick(@RequestParam("approveId") Long approveId) {
        OrderCargoControlPickApplyVO applyVO = orderCargoControlPickService.approvalOrderCargoControlPick(approveId);
        return success(applyVO);
    }

    @GetMapping("cancel/info/{id}")
    @ApiOperation("根据放货ID查询控货订单取消放货审核详情")
    @ApiImplicitParam(name = "id", value = "放货记录ID", required = true, example = "1024", dataType = "Long")
    @PreAuthenticated
    public CommonResult<OrderCargoControlPickApplyVO> approvalCancelCargoControlPickByCargoControlPickId(@PathVariable(value = "id") Long id) {
        OrderCargoControlPickApplyVO applyVO = orderCargoControlPickService.approvalUpdateCargoControlPickByCargoControlPickId(id);
        return success(applyVO);
    }

    @GetMapping("update/info/{id}")
    @ApiOperation("根据放货ID查询控货订单放货修改审核详情")
    @ApiImplicitParam(name = "id", value = "放货记录ID", required = true, example = "1024", dataType = "Long")
    @PreAuthenticated
    public CommonResult<OrderCargoControlPickApplyVO> approvalUpdateCargoControlPickByCargoControlPickId(@PathVariable(value = "id") Long id) {
        OrderCargoControlPickApplyVO applyVO = orderCargoControlPickService.approvalUpdateCargoControlPickByCargoControlPickId(id);
        return success(applyVO);
    }

    @GetMapping("anti-checking/info/{orderId}")
    @ApiOperation("根据订单ID查询控货订单放货反复核审核详情")
    @ApiImplicitParam(name = "orderId", value = "订单ID", required = true, example = "1024", dataType = "Long")
    @PreAuthenticated
    public CommonResult<OrderCargoControlPickApplyVO> approvalAntiCheckingOrderCargoControlPickByOrderId(@PathVariable(value = "orderId") Long orderId) {
        OrderCargoControlPickApplyVO applyVO = orderCargoControlPickService.approvalAntiCheckingOrderCargoControlPickByOrderId(orderId);
        return success(applyVO);
    }

    @GetMapping("cancel/approval/{orderApprovalId}")
    @ApiOperation("根据审批id取消审批")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderApprovalId", value = "审批ID", required = true, example = "1024", dataType = "Long"),
            @ApiImplicitParam(name = "reason", value = "取消原因", required = true, example = "1024", dataType = "String")
    })
    @PreAuthenticated
    @Deprecated
    public CommonResult<Boolean> cancelApprovalByOrderApprovalId(@PathVariable(value = "orderApprovalId") Long orderApprovalId,
                                                                 @RequestParam(value = "reason") String reason) {
        orderCargoControlPickService.cancelApprovalByOrderApprovalId(orderApprovalId, reason);
        return success(Boolean.TRUE);
    }

}
