package cn.iocoder.yudao.module.order.controller.app.orderControlLog;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;
import cn.iocoder.yudao.module.order.convert.orderControlLog.OrderControlLogConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.orderControlLog.OrderControlLogDO;
import cn.iocoder.yudao.module.order.service.orderControlLog.OrderControlLogService;
import cn.iocoder.yudao.module.order.vo.orderControlLog.OrderControlLogBackVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "app-web - 订单控货日志")
@RequestMapping("/order/order-control-log")
public class AppOrderControlLogController {

    @Resource
    private OrderControlLogService orderControlLogService;

    @GetMapping("/get")
    @ApiOperation("获得订单控货日志")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<OrderControlLogBackVO> getOrderControlLog(@RequestParam("id") Long id) {
        OrderControlLogDO orderControlLog = orderControlLogService.getOrderControlLog(id);
        return success(OrderControlLogConvert.INSTANCE.convert(orderControlLog));
    }

    @GetMapping("/list/{orderId}")
    @ApiOperation("获得订单控货日志列表")
    @ApiImplicitParam(name = "orderId", value = "订单id", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthenticated
    public CommonResult<List<OrderControlLogBackVO>> getOrderControlLogListByOrderId(@PathVariable("orderId") Long orderId) {
        List<OrderControlLogDO> list = orderControlLogService.getOrderControlLogListByOrderId(orderId, null);
        return success(OrderControlLogConvert.INSTANCE.convertList(list));
    }

}
