package cn.iocoder.yudao.module.order.controller.app.orderException;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.module.order.convert.orderException.OrderExceptionConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.orderException.OrderExceptionDO;
import cn.iocoder.yudao.module.order.service.orderException.OrderExceptionService;
import cn.iocoder.yudao.module.order.vo.orderException.OrderExceptionBackVO;
import cn.iocoder.yudao.module.order.vo.orderException.OrderExceptionResultHandlerVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "客户端 - 异常处理")
@RequestMapping("/ecw/order-exception")
public class AppOrderExceptionController {

    @Resource
    private OrderExceptionService orderExceptionService;


    @GetMapping("/getExceptionListByOrderId")
    @ApiOperation("根据订单ID获取所有的订单异常列表")
    @ApiImplicitParam(name = "orderId", value = "订单ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<List<OrderExceptionBackVO>> getOrderExceptionListByOrderId(@RequestParam("orderId") Long orderId) {
        List<OrderExceptionBackVO> list =
                orderExceptionService.getOrderExceptionListByOrderId(orderId);
        return success(list);
    }

    @GetMapping("/getExceptionById")
    @ApiOperation("根据ID获得异常")
    @ApiImplicitParam(name = "id", value = "id", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderExceptionBackVO> getOrderException(@RequestParam("id") Long id) {
        OrderExceptionDO orderException = orderExceptionService.getOrderException(id);
        return success(OrderExceptionConvert.INSTANCE.convert(orderException));
    }


    @PostMapping("/handlerExceptionByExceptionId")
    @ApiOperation("根据异常ID进行异常处理")
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> handlerExceptionByExceptionId(@Validated @RequestBody OrderExceptionResultHandlerVo orderExceptionResultHandlerVo) {
        orderExceptionResultHandlerVo.setSource("mobile");
        orderExceptionService.handlerExceptionByExceptionId(orderExceptionResultHandlerVo);
        return success(true);
    }

}
