package cn.iocoder.yudao.module.order.controller.app.orderTime;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.module.order.service.order.OrderTimeService;
import cn.iocoder.yudao.module.order.vo.orderTime.OrderTimeBackVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Objects;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.error;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.module.order.enums.ErrorCodeConstants.ORDER_NO_NOT_NULL;
import static cn.iocoder.yudao.module.order.enums.ErrorCodeConstants.ORDER_NO_OR_BILL_LADING_NO_NOT_NULL;

@Validated
@RestController
@Api(tags = "客户端 - 下单时间轴事件")
@RequestMapping("/order/order-time")
public class AppOrderTimeController {

    @Autowired
    private OrderTimeService orderTimeService;




    @GetMapping("/list")
    @ApiOperation("获得订单物流信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "订单ID", example = "1024", dataTypeClass = Long.class),
            @ApiImplicitParam(name = "orderNo", value = "订单编号(也可以是提单号)", example = "NA2200001F", dataTypeClass = String.class)
    })
    @Idempotent(timeout = 3, message = "正在查询中...请稍等！")
    public CommonResult<List<OrderTimeBackVO>> getOrderTimeList(@RequestParam(value = "orderId", required = false) Long orderId,
                                                                @RequestParam(value = "orderNo", required = false) String orderNo) {
        if (Objects.isNull(orderId) && StringUtils.isBlank(orderNo)) {
            return error(ORDER_NO_OR_BILL_LADING_NO_NOT_NULL);
        }
        return success(orderTimeService.orderTimeList(orderId, orderNo));
    }


}
