package cn.iocoder.yudao.module.order.controller.app.orderWarehouseIn;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.dict.core.dto.DictDataRespDTO;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;
import cn.iocoder.yudao.module.order.service.orderWarehouseIn.OrderWarehouseInService;
import cn.iocoder.yudao.module.order.vo.orderWarehouseIn.OrderWarehouseInBackVO;
import cn.iocoder.yudao.module.order.vo.orderWarehouseIn.OrderWarehouseInRollbackApplyReqVO;
import cn.iocoder.yudao.module.system.api.dict.DictDataApi;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;

import java.util.List;

import static cn.iocoder.yudao.framework.apollo.core.constants.Constants.CUSTOMER_USER_APPROVAL_ID;
import static cn.iocoder.yudao.framework.apollo.core.constants.Constants.CUSTOMER_USER_TO_ADMIN;
import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "APP -  订单仓库相关接口")
@RequestMapping("/order/order-warehouse-in")
public class AppOrderWarehouseInController {

    @Resource
    private OrderWarehouseInService orderWarehouseInService;

    @Resource
    private DictDataApi dictDataApi;


    @PutMapping("/rollback-apply")
    @ApiOperation("退仓-发起审批请求")
    @PreAuthenticated
    public CommonResult<Boolean> orderWarehouseInRollbackApply(@Valid @RequestBody OrderWarehouseInRollbackApplyReqVO orderWarehouseInRollbackApplyReqVO) {

        DictDataRespDTO dto = dictDataApi.parseDictDataFromCache(CUSTOMER_USER_TO_ADMIN, CUSTOMER_USER_APPROVAL_ID);
        Long userId = Long.valueOf(dto.getValue());

        String reason = orderWarehouseInRollbackApplyReqVO.getReason();
        orderWarehouseInRollbackApplyReqVO.setReason("【客户端发起退仓申请】" + (StringUtils.isEmpty(reason) ? "" : reason));

        orderWarehouseInService.rollbackApply(orderWarehouseInRollbackApplyReqVO, userId, true);
        return success(true);
    }


    @GetMapping("/get-order-warehouse-in")
    @ApiOperation("获得订单的入仓货物详情")
    @ApiImplicitParam(name = "orderId", value = "订单id", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<List<OrderWarehouseInBackVO>> getOrderWarehouseIn(@RequestParam("orderId") Long orderId) {
        List<OrderWarehouseInBackVO> orderWarehouseInBackVOList = orderWarehouseInService.getOrderWarehouseInList(orderId);
        return success(orderWarehouseInBackVOList);
    }


}
