package cn.iocoder.yudao.module.order.controller.app.orderWarehousePicture;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.order.convert.orderWarehousePicture.OrderWarehousePictureConvert;
import cn.iocoder.yudao.module.order.dal.dataobject.orderWarehousePicture.OrderWarehousePictureDO;
import cn.iocoder.yudao.module.order.service.orderWarehousePicture.OrderWarehousePictureService;
import cn.iocoder.yudao.module.order.vo.orderWarehousePicture.OrderWarehousePictureBackVO;
import cn.iocoder.yudao.module.order.vo.orderWarehousePicture.OrderWarehousePictureCreateReqVO;
import cn.iocoder.yudao.module.order.vo.orderWarehousePicture.OrderWarehousePictureQueryVO;
import cn.iocoder.yudao.module.order.vo.orderWarehousePicture.OrderWarehousePictureUpdateReqVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

@Validated
@RestController
@Api(tags = "APP -  订单仓库图片")
@RequestMapping("/order/warehouse-picture")
public class AppOrderWarehousePictureController {

    @Resource
    private OrderWarehousePictureService warehousePictureService;


    @PostMapping("/list")
    @ApiOperation("获得订单入仓/调仓/转异/报关资料等的图片列表")
    public CommonResult<List<OrderWarehousePictureBackVO>> getWarehousePictureList(@Valid @RequestBody OrderWarehousePictureQueryVO orderWarehousePictureQueryVO) {
        List<OrderWarehousePictureDO> list = warehousePictureService.getWarehousePictureList(orderWarehousePictureQueryVO);
        return success(OrderWarehousePictureConvert.INSTANCE.convertList(list));
    }


    @PostMapping("/create")
    @ApiOperation("上传图片")
    public CommonResult<Long> createWarehousePicture(@Valid @RequestBody OrderWarehousePictureCreateReqVO createReqVO) {
        return success(warehousePictureService.createWarehousePicture(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新订单仓库图片")
    public CommonResult<Boolean> updateWarehousePicture(@Valid @RequestBody OrderWarehousePictureUpdateReqVO updateReqVO) {
        warehousePictureService.updateWarehousePicture(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除订单仓库图片")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteWarehousePicture(@RequestParam("id") Long id) {
        warehousePictureService.deleteWarehousePicture(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得订单仓库图片")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderWarehousePictureBackVO> getWarehousePicture(@RequestParam("id") Long id) {
        OrderWarehousePictureDO warehousePicture = warehousePictureService.getWarehousePicture(id);
        return success(OrderWarehousePictureConvert.INSTANCE.convert(warehousePicture));
    }

    // @GetMapping("/list")
    // @ApiOperation("获得订单仓库图片列表")
    // @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    // public CommonResult<List<OrderWarehousePictureBackVO>> getWarehousePictureList(@RequestParam("ids") Collection<Long> ids) {
    //     List<OrderWarehousePictureDO> list = warehousePictureService.getWarehousePictureList(ids);
    //     return success(OrderWarehousePictureConvert.INSTANCE.convertList(list));
    // }

    @GetMapping("/page")
    @ApiOperation("获得订单仓库图片分页")
    public CommonResult<PageResult<OrderWarehousePictureBackVO>> getWarehousePicturePage(@Valid OrderWarehousePictureQueryVO query, PageVO page) {
        PageResult<OrderWarehousePictureDO> pageResult = warehousePictureService.getWarehousePicturePage(query, page);
        return success(OrderWarehousePictureConvert.INSTANCE.convertPage(pageResult));
    }
}
